<?php
/**
 * CPT
 *
 * @package Capture
 */

defined( 'WPINC' ) || exit;

/**
 * Single sections
 */
class Capture_CPT extends Capture_Base {

	/**
	 * The Construct
	 */
	public function __construct() {
		$this->add_action( 'init', 'photo_custom_post_type' );
	}

	/**
	 * Creating a function to create our Photos CPT.
	 */
	public function photo_custom_post_type() {

		// Set UI labels for Custom Post Type.
		$labels = [
			'name'               => _x( 'Photos', 'Post Type General Name', 'capture' ),
			'singular_name'      => _x( 'Photo', 'Post Type Singular Name', 'capture' ),
			'menu_name'          => __( 'Photos', 'capture' ),
			'parent_item_colon'  => __( 'Parent Photo', 'capture' ),
			'all_items'          => __( 'All Photos', 'capture' ),
			'view_item'          => __( 'View Photo', 'capture' ),
			'add_new_item'       => __( 'Add New Photo', 'capture' ),
			'add_new'            => __( 'Add New', 'capture' ),
			'edit_item'          => __( 'Edit Photo', 'capture' ),
			'update_item'        => __( 'Update Photo', 'capture' ),
			'search_items'       => __( 'Search Photo', 'capture' ),
			'not_found'          => __( 'Not Found', 'capture' ),
			'not_found_in_trash' => __( 'Not found in Trash', 'capture' ),
		];

		// Set other options for Custom Post Type.
		$args = [
			'label'               => __( 'photos', 'capture' ),
			'menu_icon'           => 'dashicons-sticky',
			'description'         => __( 'Photo posts', 'capture' ),
			'labels'              => $labels,
			'supports'            => [ 'title', 'editor', 'excerpt', 'author', 'thumbnail', 'comments', 'revisions', 'custom-fields' ],
			'taxonomies'          => [ 'photos' ],
			'hierarchical'        => false,
			'public'              => true,
			'show_ui'             => true,
			'show_in_menu'        => true,
			'show_in_nav_menus'   => true,
			'show_in_admin_bar'   => true,
			'menu_position'       => 5,
			'can_export'          => true,
			'has_archive'         => true,
			'exclude_from_search' => true,
			'publicly_queryable'  => true,
			'capability_type'     => 'post',
			'show_in_rest'        => true,
			'rewrite'             => [ 'slug' => 'photos' ], // Permalinks format.
		];

		register_post_type( 'photos', $args );

		register_taxonomy(
			'photos_categories',
			'photos',
			[
				'show_admin_column' => true,
				'hierarchical'      => true,
				'show_in_rest'      => true,
				'show_ui'           => true,
				'query_var'         => true,
				'rewrite'           => [
					'slug' => 'photos-category',
				],
			]
		);

		register_taxonomy(
			'photos_tag',
			'photos',
			[
				'show_admin_column' => true,
				'has_archive'       => true,
				'hierarchical'      => false,
				'show_in_rest'      => true,
				'rewrite'           => [
					'slug' => 'photos-tag',
				],
			]
		);

	}

}

/**
 * Init
 */
new Capture_CPT();
