<?php
/**
 * Set capture layout according to options
 *
 * @package Capture
 */

defined( 'WPINC' ) || exit;

/**
 * Layout manager.
 */
class Capture_Layout extends Capture_Base {

	/**
	 * The Construct
	 */
	public function __construct() {
		$this->add_action( 'capture_before_wrapper', 'add_header' );
		$this->add_action( 'capture_single_post_full_header', 'single_post_full_header' );
		$this->add_action( 'capture_single_post_header_thumb', 'single_post_header_thumb' );
		$this->add_action( 'capture_single_photo_header_thumb', 'single_photo_header_thumb' );
		$this->add_action( 'capture_single_photos_thumbnail', 'single_photos_thumbnail' );
		$this->add_action( 'capture_blog_page_title_section', 'blog_page_title_section' );
		$this->add_action( 'capture_single_photos_full_header', 'single_photos_full_header' );
		$this->add_action( 'capture_single_photos_header_gallery', 'single_photos_header_gallery' );
		$this->add_action( 'capture_before_footer', 'full_related_posts' );
		$this->add_action( 'capture_full_photo_related_posts', 'full_photo_related_posts' );
	}


	/**
	 * Add header
	 */
	public function add_header() {
		$hash   = [
			'header-default' => 'default',
			'header-layout2' => 'layout2',
		];
		$layout = capture_get_settings( 'header_styles' );
		get_template_part( 'template-parts/header/header', isset( $hash[ $layout ] ) ? $hash[ $layout ] : $layout );
	}

	/**
	 * Blog Page Title
	 */
	public function blog_page_title_section() {
		$show_blog_title    = capture_get_settings( 'show_blog_title' );
		$show_blog_subtitle = capture_get_settings( 'show_blog_subtitle' );
		if ( empty( $show_blog_title ) && empty( $show_blog_subtitle ) ) {
			return;
		}
		if ( ( $show_blog_title || $show_blog_subtitle ) && ! is_paged() ) :
			$blog_title    = capture_get_settings( 'blog_title' );
			$blog_subtitle = capture_get_settings( 'blog_subtitle' );
			if ( ! empty( $blog_title ) || $blog_subtitle ) :
				echo '<div class="pages-title-section">';
				echo '<div class="container">';
				if ( ! empty( $blog_title ) ) {
					echo '<div class="blog-heading">' . $blog_title . '</div>';
				}
				if ( ! empty( $blog_subtitle ) ) {
					echo '<div class="blog-subheading">' . $blog_subtitle . '</div>';
				}
				echo '</div>';
				echo '</div>';
			endif;
		endif;
	}

	/**
	 * Single post header thumbnail
	 */
	public function single_post_header_thumb() {
		$img_size = capture_get_settings( 'featured_image_size' );
		if ( 'default' !== $img_size ) {
			return;
		}
		?>
		<header>
			<?php
			capture_the_post_meta( 'single' );
			?>
			<h1 class="single-title"><?php the_title(); ?></h1>
		</header>
		<?php
	}

	/**
	 * Single post header thumbnail
	 */
	public function single_photo_header_thumb() {
		$photo_size = capture_get_settings( 'header_photos_image_size' );
		if ( 'default' !== $photo_size ) {
			return;
		}
		?>
		<header>
			<?php
			capture_the_post_meta( 'photos' );
			?>
			<h1 class="single-title"><?php the_title(); ?></h1>
		</header>
		<?php
	}

	/**
	 * Single post header if fullwidth layout
	 */
	public function single_post_full_header() {

		$img_size = capture_get_settings( 'featured_image_size' );

		if ( 'full' !== $img_size ) {
			return;
		}
		if ( have_posts() ) :
			while ( have_posts() ) :
				the_post();
				?>
				<div class="single-full-header single-header clearfix">
					<div class="container">
						<?php capture_single_full_header_content(); ?>
					</div>
				</div>
				<?php
			endwhile;
		endif; /* end loop */

	}

	/**
	 * Single post header if fullwidth layout
	 */
	public function single_photos_thumbnail() {

		if ( ! has_post_thumbnail() ) {
			return;
		}
		// Parallax and Zoomout effect.
		capture_single_featured_image_effect();
		$header_animation = capture_get_post_header_effect();
		if ( ! $header_animation && capture_get_settings( 'show_single_featured' ) ) {
			echo '<div class="single-featured-image">';
			echo '<div class="container">';
			the_post_thumbnail( 'capture-full-width-layout', [ 'title' => '' ] );
			echo '</div>';
			echo '</div>';
		}

	}

	/**
	 * Single post header if fullwidth layout
	 */
	public function single_photos_full_header() {

		$photo_size = capture_get_settings( 'header_photos_image_size' );

		if ( 'full' !== $photo_size ) {
			return;
		}
		if ( have_posts() ) :
			while ( have_posts() ) :
				the_post();
				?>
				<div class="single-full-header single-cpt-photo clearfix">
					<div class="container">
						<?php capture_single_full_header_content( 'photos' ); ?>
					</div>
				</div>
				<?php
			endwhile;
		endif; /* end loop */
	}

	/**
	 * Single Photos Header Gallery
	 */
	public function single_photos_header_gallery() {
		$files = get_post_meta( get_the_ID(), 'photo_info_gallery', 1 );
		$args  = [
			'post_type'      => 'attachment',
			'numberposts'    => -1,
			'post_parent'    => get_the_ID(),
			'order'          => 'ASC',
			'orderby'        => 'menu_order',
			'post_mime_type' => 'image',
		];
		// args.
		$args        = apply_filters( 'capture_single_photos_images_args', $args, get_the_ID() );
		$attachments = get_posts( $args );
		if ( $files ) {
			?>
			<div class="single-featured-image">
				<div class="container">
					<div class="photo-slider-container clearfix loading">
						<div id="slider" class="photo-slider">
						<?php
						// Loop through them and output an image.
						foreach ( (array) $files as $attachment_id => $attachment_url ) {
							$src = wp_get_attachment_image_src( $attachment_id, 'capture-full-width-layout' );
							echo '<div class="slide"><div class="container"><img src=" ' . esc_url( $src[0] ) . '" /></div></div>';
						}
						?>
						</div>
					</div>
				</div>
			</div>
			<?php
		} elseif ( $attachments && count( $attachments ) > 1 ) {
			?>
			<div class="single-featured-image">
				<div class="container">
					<div class="photo-slider-container clearfix loading">
						<div id="slider" class="photo-slider">
							<?php
							foreach ( $attachments as $attachment ) {
								$id  = $attachment->ID;
								$src = wp_get_attachment_image_src( $id, 'capture-full-width-layout' );
								echo '<div class="slide"><div class="container"><img src=" ' . esc_url( $src[0] ) . '" /></div></div>';
							}
							?>
						</div>
					</div><!-- .photo-slider-container -->
				</div>
			</div>
			<?php
		} elseif ( has_post_thumbnail() && capture_get_settings( 'show_single_featured' ) ) {
			?>
			<div class="single-featured-image">
				<div class="container">
					<?php the_post_thumbnail( 'capture-full-width-layout', [ 'title' => '' ] ); ?>
				</div>
			</div>
			<?php
		}
		?>
		</div>
	</div>
		<?php
	}

	/**
	 * Full Related Posts.
	 *
	 * @param $position
	 */
	public function full_related_posts( $position = 'full' ) {
		$position = capture_get_settings( 'related_posts_position' );
		if ( 'full' === $position ) {
			capture_related_posts();
		}
	}

	/**
	 * Full Photo Related Posts.
	 *
	 * @param $position
	 */
	public function full_photo_related_posts( $position = 'full' ) {
		$position = capture_get_settings( 'related_posts_position' );
		$enabled  = ! empty( capture_get_settings( 'mts_single_photos_layout' )['enabled']['related'] ) ? 'Related Posts' : '';
		if ( 'full' === $position && 'Related Posts' === $enabled ) {
			capture_photos_related_posts();
		}
	}

}

// Init.
new Capture_Layout();
