<?php
/**
 * Metaboxes
 *
 * @package Capture
 */

defined( 'WPINC' ) || exit;

/**
 * Single sections
 */
class Capture_Metaboxes extends Capture_Base {

	/**
	 * The Construct
	 */
	public function __construct() {
		$this->add_action( 'cmb2_admin_init', 'capture_photos_metaboxes' );
	}

	/**
	 * Define the metabox configurations for photos CPT.
	 */
	function capture_photos_metaboxes() {

		/**
		 * Initiate the metabox
		 */
		$cmb = new_cmb2_box(
			[
				'id'           => 'photo_cpt_metabox',
				'title'        => esc_html__( 'Photos Info', 'capture' ),
				'object_types' => [ 'photos' ], // Post type.
				'context'      => 'normal',
				'priority'     => 'high',
				'show_names'   => true, // Show field names on the left.
			]
		);

		$cmb->add_field(
			[
				'id'           => 'photo_info_gallery',
				'name'         => __( 'Gallery Images', 'capture' ),
				'desc'         => __( 'Upload or Select Gallery Images from here. NOTE: If this option is empty, then slider will show attached images to this post.', 'capture' ),
				'type'         => 'file_list',
				'preview_size' => [ 100, 100 ],
				'text'         => [
					'add_upload_files_text' => __( 'Add or Upload Images', 'capture' ), // Add or Upload Files.
				],
			]
		);

		$photo_info_group = $cmb->add_field(
			[
				'id'          => 'photo_info_group',
				'type'        => 'group',
				'description' => esc_html__( 'Add more info for photos', 'capture' ),
				'options'     => [
					'group_title'   => esc_html__( 'Field {#}', 'capture' ),
					'add_button'    => esc_html__( 'Add More Field', 'capture' ),
					'remove_button' => esc_html__( 'Remove Field', 'capture' ),
					'sortable'      => true,
				],
			]
		);

		// Id's for group's fields only need to be unique for the group. Prefix is not needed.
		$cmb->add_group_field(
			$photo_info_group,
			[
				'name' => 'Field Title',
				'id'   => 'title',
				'type' => 'text',
			]
		);
		$cmb->add_group_field( 
			$photo_info_group,
			[
				'name' => 'Field Value',
				'id'   => 'value',
				'type' => 'text',
			]
		);

	}

}

/**
 * Init
 */
new Capture_Metaboxes;
