<?php
/**
 * CPT
 *
 * @package Capture
 */

defined( 'WPINC' ) || exit;

/**
 * Single sections
 */
class Capture_Photos_Single extends Capture_Single_Sections {

	/**
	 * The Construct
	 */
	public function __construct() {
		$this->add_action( 'capture_photos_content', 'get_photo_single_sections', 10 );
	}

	/**
	 * Photos single page structure
	 */
	public function get_photo_single_sections() {
		?>

		<article class="<?php capture_article_class(); ?>">
			<div id="content_box">
				<?php
				// Elementor 'single' location.
				if ( ! capture_is_elementor( 'single' ) ) {
					if ( have_posts() ) :
						while ( have_posts() ) :
							the_post();
							capture_breadcrumbs();
							?>
							<div id="post-<?php the_ID(); ?>" <?php post_class( 'g post' ); ?>>
								<?php
								// Single post parts ordering.
								if ( ( null !== capture_get_settings( 'mts_single_photos_layout' ) ) && is_array( capture_get_settings( 'mts_single_photos_layout' ) ) && array_key_exists( 'enabled', capture_get_settings( 'mts_single_photos_layout' ) ) ) {
									$single_post_parts = capture_get_settings( 'mts_single_photos_layout' )['enabled'];
								} else {
									$single_post_parts = [
										'content'   => 'content',
										'tags'      => 'tags',
										'author'    => 'author',
										'subscribe' => 'subscribe',
									];
								}

								foreach ( $single_post_parts as $part => $label ) {
									switch ( $part ) {
										// Content area.
										case 'content':
											$this->single_post();
											break;

										// Tags & Social.
										case 'tags':
											echo '<div class="social-tags">';
											capture_post_tags( '<div class="tags"><div class="tagtext">' . esc_html__( 'Tags', 'capture' ) . '</div>', '', '</div>', 'photos_tag' );
											$this->single_post_social_icons();
											echo '</div>';
											break;

										// Author box.
										case 'author':
											$this->single_author_section();
											break;

										// Related Posts.
										case 'related':
											if ( 'default' === capture_get_settings( 'related_posts_position' ) ) {
												capture_photos_related_posts();
											}
											break;

										// Subscribe box.
										case 'subscribe':
											$this->single_subscribe_box();
											break;
									}
								}
								?>
							</div><!--.g post-->
							<?php
							// Comment area.
							comments_template( '', true );
						endwhile;
						wp_reset_postdata();
				endif; /* end loop */
				}
				?>
			</div>
		</article>

		<?php
	}

	/**
	 * Single Post Structure
	 */
	public function single_post() {
		?>
		<div class="single_post">

			<?php

			capture_action( 'single_photo_header_thumb' );
			?>
			<div class="photos-single-left">
				<div class="post-single-content box mark-links entry-content">

					<?php
					$this->single_post_ads( 'above' );

					$this->single_post_content();

					$this->single_post_pagination();

					$this->single_post_ads( 'below' );

					?>

				</div><!--.post-single-content-->
			</div>
			<?php
			$this->get_model_photos_info();
			?>

		</div><!--.single_post-->
		<?php
	}

	/**
	 * Get model photos info
	 */
	public function get_model_photos_info() {

		$all_info = get_post_meta( get_the_ID(), 'photo_info_group', true );

		if ( ! $all_info ) {
			return;
		}

		echo '<div class="model-photos-infos">';

		foreach ( $all_info as $info ) {
			printf(
				'<div class="model-photos-info">
					<div class="model-title">%1$s</div>
					<div class="model-description">%2$s</div>
				</div>',
				esc_attr( $info['title'] ),
				esc_attr( $info['value'] )
			);
		}

		echo '</div>';

	}

}

/**
 * Init
 */
new Capture_Photos_Single();
