<?php
/**
 * Photos
 *
 * @package Capture
 */

defined( 'WPINC' ) || exit;

/**
 * Main class for Photos CPT
 */
class Capture_Photos extends Capture_Base {

	/**
	 * The Construct
	 */
	public function __construct() {
		$this->add_action( 'capture_photos_posts', 'get_photos_articles' );
		$this->add_action( 'capture_get_photo_thumbnail', 'get_post_thumbnail' );
		$this->add_action( 'capture_get_photo_pagination', 'get_pagination' );
	}

	/**
	 * Get posts from photos CPT
	 */
	public function get_photos_articles() {

		$args = self::get_photos_query_args();

		$ph_query = new WP_Query( $args );

		$post_hover = capture_get_settings( 'photos_hover' );
		$class      = $post_hover ? 'post-hover' : '';

		while ( $ph_query->have_posts() ) {
			$ph_query->the_post();
			?>

			<article <?php post_class( 'latestPost excerpt ' . $class . ' ' ); ?> id="post-<?php the_ID(); ?>">

				<?php $this->get_post_thumbnail( get_the_ID() ); ?>

			</article>

			<?php
		}

		$this->get_pagination();

		wp_reset_postdata();
	}

	/**
	 * Get post thumbnail
	 *
	 * @param num $id post id.
	 */
	public function get_post_thumbnail( $id ) {

		$thumb   = 'capture-photos-featured';
		$like    = get_simple_likes_button( $id );
		$likebtn = capture_get_settings( 'photo_like_button' );
		?>

		<a<?php capture_attr( 'post_thumb_url', $id ); ?>>
			<div class="featured-thumbnail">
				<?php
				if ( has_post_thumbnail() ) {
					the_post_thumbnail( $thumb, [ 'title' => '' ] );
				} else {
					echo '<img src="' . get_template_directory_uri() . '/images/nothumb-' . $thumb . '.png" alt="' . __( 'No Preview', 'capture' ) . '"  class="wp-post-image" />'; // phpcs:ignore
				}
				?>
			</div>
			<?php
			if ( $likebtn ) :
				echo '<div class="photo-like-button">' . $like . '</div>'; // phpcs:ignore
			endif;
			?>
		</a>

		<?php
	}

	/**
	 * Get pagination
	 */
	public function get_pagination() {

		capture_pagination( capture_get_settings( 'photo_pagenavigation_type' ) );

	}
	/**
	 * Default Query args for Photos CPT.
	 *
	 * @param array $new_args new arguments.
	 */
	public static function get_photos_query_args( $new_args = [] ) {

		global $paged;

		if ( get_query_var( 'paged' ) ) {
			$paged = get_query_var( 'paged' ); // phpcs:ignore
		} elseif ( get_query_var( 'page' ) ) {
			$paged = get_query_var( 'page' ); // phpcs:ignore
		} else {
			$paged = 1; // phpcs:ignore
		}
		$ph_post_num = capture_get_settings( 'photo_post_num' );

		$args = [
			'post_type'           => 'photos',
			'post_status'         => 'publish',
			'ignore_sticky_posts' => 1,
			'posts_per_page'      => $ph_post_num,
			'paged'               => $paged,
		];

		return array_merge( $args, $new_args );
	}

}

/**
 * Init
 */
new Capture_Photos();
