<?php
/**
 * Script enqueueing manager.
 *
 * @package Capture
 */

defined( 'WPINC' ) || exit;

/**
 * Script enqueueing manager.
 */
class Capture_Scripts extends Capture_Base {

	/**
	 * The Constructor
	 */
	public function __construct() {

		if ( ! is_admin() && ! in_array( $GLOBALS['pagenow'], [ 'wp-login.php', 'wp-register.php' ] ) ) {

			$this->add_action( 'wp_enqueue_scripts', 'enqueue_scripts' );

			if ( capture_get_settings( 'optimize_wc' ) ) {

				$this->add_action( 'wp_enqueue_scripts', 'remove_woocommerce_scripts', 99 );

				// Remove WooCommerce generator tag.
				remove_action( 'wp_head', 'wc_generator_tag' );
			}

			if ( capture_get_settings( 'async_js' ) ) {
				$this->add_filter( 'script_loader_tag', 'add_async', 10, 2 );
			}

			if ( capture_get_settings( 'remove_ver_params' ) ) {
				$this->add_filter( 'script_loader_src', 'remove_version', 99 );
				$this->add_filter( 'style_loader_src', 'remove_version', 99 );
			}
		}
	}

	/**
	 * Takes care of enqueueing all our scripts.
	 */
	public function enqueue_scripts() {
		$this->styles();
		$this->scripts();
	}

	/**
	 * Enqueue CSS files
	 */
	private function styles() {
		$version            = capture()->get_version();
		$template_directory = get_template_directory_uri();

		// style.css file.
		wp_enqueue_style( 'capture-theme', $template_directory . '/style.css', [], $version );

		$deps = 'capture-theme';

		// Font Awesome.
		$this->font_styles();
		wp_enqueue_style( 'fontawesome', $template_directory . '/css/font-awesome.min.css', $deps, '4.7.0' );

		// Slider.
		if ( is_singular( 'photos' ) ) :
			wp_enqueue_style( 'owl-carousel', $template_directory . '/css/owl.carousel.css', $deps, $version );
		endif;

		// Responsive.
		if ( capture_get_settings( 'mts_responsive', false ) ) {
			wp_enqueue_style( 'capture-responsive', $template_directory . '/css/capture-responsive.css', $deps, $version );
		}

		// WooCommerce.
		if ( capture_is_woocommerce_active() ) {
			wp_enqueue_style( 'capture-woocommerce', $template_directory . '/css/capture-woocommerce.css', 'woocommerce', $version );
		}

		// Lightbox.
		if ( capture_get_settings( 'enable_lightbox' ) ) {
			wp_enqueue_style( 'magnificPopup', $template_directory . '/css/magnific-popup.css', $deps, $version );
		}

	}

	/**
	 * Enqueue JS files
	 */
	private function scripts() {

		$version            = capture()->get_version();
		$template_directory = get_template_directory_uri();
		$deps               = [ 'jquery' ];

		// The comment-reply script.
		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}

		// Ad Blocker Detector.
		if ( ! empty( capture_get_settings( 'detect_adblocker' ) ) ) {
			wp_enqueue_script( 'AdBlockerDetector', get_template_directory_uri() . '/js/ads.js' );
		}

		// Main theme script.
		wp_register_script( 'capture_customscript', $template_directory . '/js/capture-customscripts.js', $deps, $version, true );

		// Localize for Responsive Menu.
		$nav_menu = 'none';
		if ( ! empty( capture_get_settings( 'dropdown_menu' ) ) ) {
			$nav_menu = 'both';
		} else {
			$nav_menu = 'primary';
		}
		wp_localize_script(
			'capture_customscript',
			'capture_customscript',
			[
				'nav_menu'   => $nav_menu,
				'responsive' => ( empty( capture_get_settings( 'mts_responsive' ) ) ? false : true ),
				'layout'     => capture_get_settings( 'header_styles' ),
				'show'       => capture_get_settings( 'show_top_button' ),
				'icon'       => capture_get_settings( 'top_button_icon' ),
			]
		);
		wp_enqueue_script( 'capture_customscript' );

		// Slider.
		if ( is_singular( 'photos' ) ) :
			wp_enqueue_script( 'owl-carousel', $template_directory . '/js/owl.carousel.min.js', $deps, $version, true );
		endif;

		// Animated Single Post or Page header.
		wp_register_script( 'capture-parallax', $template_directory . '/js/capture-parallax.js', $deps, $version, true );
		wp_register_script( 'capture-zoomout', $template_directory . '/js/capture-zoomout.js', $deps, $version, true );
		if ( is_singular() ) {
			$header_animation = capture_get_post_header_effect();
			if ( 'parallax' === $header_animation ) {
				wp_enqueue_script( 'capture-parallax' );
			} elseif ( 'zoomout' === $header_animation ) {
				wp_enqueue_script( 'capture-zoomout' );
			}
		}

		// Lightbox.
		if ( capture_get_settings( 'enable_lightbox' ) ) {
			wp_register_script( 'magnificPopup', $template_directory . '/js/jquery.magnific-popup.min.js', $deps, $version, true );
			wp_localize_script(
				'magnificPopup',
				'magnificPopup',
				[
					'readmore_title' => capture_get_settings( 'photo_readmore_title' ),
					'readmore_btn'   => capture_get_settings( 'photo_readmore_button' ),
					'like_btn'       => capture_get_settings( 'photo_like_button' ),
				]
			);
			wp_enqueue_script( 'magnificPopup' );
		}

		// Sticky Navigation.
		if ( ! empty( capture_get_settings( 'sticky_nav' ) ) ) {
			wp_enqueue_script( 'StickyNav', $template_directory . '/js/sticky.js', $deps, $version, true );
		}

		// Ajax Load More and Search Results.
		$pagination_type = capture_get_settings( 'mts_pagenavigation_type' );
		if ( is_page_template( 'page-home.php' ) || is_post_type_archive( 'photos' ) || is_tax( 'photos_categories' ) ) {
			$pagination_type = capture_get_settings( 'photo_pagenavigation_type' );
		}

		wp_register_script( 'capture-ajax', get_template_directory_uri() . '/js/ajax.js', $deps, $version, true );
		wp_register_script( 'historyjs', get_template_directory_uri() . '/js/history.js', $deps, $version, true );
		if ( ! empty( $pagination_type ) && $pagination_type >= 2 && ! is_single() ) {

			wp_enqueue_script( 'capture-ajax' );
			wp_enqueue_script( 'historyjs' );

			$args = Capture_Photos::get_photos_query_args();

			if ( get_query_var( 'paged' ) ) {
				$paged = get_query_var( 'paged' );
			} elseif ( get_query_var( 'page' ) ) {
				$paged = get_query_var( 'page' );
			} else {
				$paged = 1;
			}
			$ph_query = new WP_Query( $args );

			// Add parameters for the JS.
			if ( is_page_template( 'page-home.php' ) || is_post_type_archive( 'photos' ) || is_tax( 'photos_categories' ) ) {
				$max = $ph_query->max_num_pages;
			} else {
				global $wp_query;
				$max = $wp_query->max_num_pages;
			}
			$autoload = ( '3' === $pagination_type );
			wp_localize_script( 'capture-ajax', 'capture_ajax_loadposts', [
				'startPage'     => $paged,
				'maxPages'      => $max,
				'nextLink'      => next_posts( $max, false ),
				'autoLoad'      => $autoload,
				'i18n_loadmore' => __( 'Load More Stories', 'capture' ) . '<i class="fa fa-angle-down"></i>',
				'i18n_loading'  => __( 'Loading...', 'capture' ),
				'i18n_nomore'   => __( 'No more posts.', 'capture' ),
			] );
		}
		if ( ! empty( capture_get_settings( 'mts_ajax_search' ) ) ) {
			wp_enqueue_script( 'capture-ajax' );
			wp_localize_script( 'capture-ajax', 'capture_ajax_search', [
				'url'         => admin_url( 'admin-ajax.php' ),
				'ajax_search' => '1',
			]);
		}

		// Google Map.
		$api = capture_get_settings( 'capture_google_map_api' );
		if ( $api ) {
			wp_enqueue_script( 'google-map', 'https://maps.googleapis.com/maps/api/js?key=' . $api, '', '' );
		}
	}

	/**
	 * Generate needed font
	 *
	 * @return void
	 */
	public function font_styles() {

		$link = get_transient( 'capture_dynamic_css_typography_link' );
		if ( false === $link ) {
			$fonts = $this->get_google_fonts();

			// If we don't have any fonts then we can exit.
			if ( empty( $fonts ) ) {
				return;
			}

			// Get font-family + subsets.
			$link_fonts = [];
			foreach ( $fonts as $font => $variants ) {

				$variants = implode( ',', $variants );

				$link_font = str_replace( ' ', '+', $font );
				if ( ! empty( $variants ) ) {
					$link_font .= ':' . $variants;
				}
				$link_fonts[] = $link_font;
			}

			$subsets = capture_get_settings( 'typography-subsets', [] );
			$link    = add_query_arg( array(
				'family' => str_replace( '%2B', '+', urlencode( implode( '|', $link_fonts ) ) ),
				'subset' => urlencode( implode( ',', $subsets ) ),
			), 'https://fonts.googleapis.com/css' );

			set_transient( 'capture_dynamic_css_typography_link', $link );
		}

		// Enqueue it.
		wp_enqueue_style( 'capture_google_fonts', $link, [], null );
	}

	/**
	 * Get typography from theme options
	 *
	 * @return array
	 */
	private function get_google_fonts() {

		$fonts      = [];
		$collection = (array) capture_get_settings( 'typography-collections', [] );

		$opts = [
			'capture_logo',
			'primary_navigation_font',
			'pagination_font',
			'loadmore_font',
			'archive_post_title_font',
			'archive_post_excerpt_font',
			'archive_meta_info_font',
			'archive_readmore_font',
			'photo_title_font',
			'photo_slider_counter_font',
			'photo_readmore_font',
			'photo_like_font',
			'photo_like_hover_font',
			'pages_title_font',
			'pages_subtitle_font',
			'breadcrumb_font',
			'single_title_font',
			'mts_single_meta_info_font',
			'single_photo_title_font',
			'single_photo_meta_info_font',
			'single_photo_nextprev_font',
			'model_title_font',
			'model_desc_font',
			'tags_social_heading',
			'tags_social_font',
			'single_page_titles_font',
			'single_subscribe_title_font',
			'single_subscribe_text_font',
			'single_subscribe_input_font',
			'single_subscribe_submit_font',
			'single_subscribe_small_text_font',
			'authorbox_title_font',
			'authorbox_author_name_font',
			'authorbox_text_font',
			'content_font',
			'sidebar_title_font',
			'sidebar_font',
			'sidebar_links_widgets',
			'sidebar_post_title',
			'sidebar_large_post_title',
			'sidebar_postinfo_font',
			'top_footer_title_font',
			'top_footer_font',
			'footer_links_widgets',
			'top_footer_post_title',
			'footer_large_post_title',
			'top_footer_meta_font',
			'copyrights_font',
			'fields_font',
			'buttons_font',
			'blockquote_font',
			'h1_headline',
			'h2_headline',
			'h3_headline',
			'h4_headline',
			'h5_headline',
			'h6_headline',
			'related_posts_font',
			'related_posts_meta_font',
			'related_posts_excerpt_font',
		];

		// Dynamic Tab Fonts.
		$features = capture_get_settings( 'featured_categories' );
		foreach ( $features as $feature ) {
			if ( ! isset( $feature['unique_id'] ) ) {
				continue;
			}
			$opts[] = 'featured_category_title_font_' . $feature['unique_id'];
			$opts[] = 'meta_info_font_' . $feature['unique_id'];
			$opts[] = 'readmore_font_' . $feature['unique_id'];
			$opts[] = 'post_title_font_' . $feature['unique_id'];
			$opts[] = 'post_excerpt_font_' . $feature['unique_id'];
		}

		foreach ( $opts as $key ) {
			$val = capture_get_settings( $key, false );

			if ( $val ) {

				// Add to collection.
				$collection[] = $val;
			}
		}

		foreach ( (array) $collection as $font ) {

			$variant = '';

			if ( isset( $font['css-selectors'] ) && empty( trim( $font['css-selectors'] ) ) ) {
				continue;
			}

			if ( empty( $font['font-family'] ) ) {
				continue;
			}

			$variant = empty( $font['font-weight'] ) || 'normal' === $font['font-weight'] ? '400' : $font['font-weight'];

			// Add "i" to font-weight to make italics properly load.
			if ( isset( $font['font-style'] ) && 'italic' === $font['font-style'] ) {
				$variant .= 'i';
			}

			// Add the requested google-font.
			if ( ! isset( $fonts[ $font['font-family'] ] ) ) {
				$fonts[ $font['font-family'] ] = [];
			}
			if ( ! in_array( $variant, $fonts[ $font['font-family'] ], true ) ) {
				$fonts[ $font['font-family'] ][] = $variant;
			}
		}

		return $fonts;
	}

	/**
	 * Add async to capture javascript file for performance
	 *
	 * @param string $tag    The script tag.
	 * @param string $handle The script handle.
	 */
	public function add_async( $tag, $handle ) {

		$to_match = array( 'capture' );
		return in_array( $handle, $to_match ) ? str_replace( ' src', ' async src', $tag ) : $tag;
	}

	/**
	 * Remove version param from script or style source url
	 *
	 * @param  string $src Script loader source path.
	 */
	public function remove_version( $src ) {

		$parts = explode( '?ver', $src );
		return $parts[0];
	}

	/**
	 * Remove WooCommerce Scripts and Styles from unneeded pages.
	 */
	public function remove_woocommerce_scripts() {

		// First check that woo exists to prevent fatal errors.
		if ( function_exists( 'is_woocommerce' ) ) {

			// Dequeue scripts and styles.
			if ( ! is_woocommerce() && ! is_cart() && ! is_checkout() && ! is_account_page() ) {
				wp_dequeue_script( 'capture-woocommerce' );
				wp_dequeue_style( 'woocommerce-layout' );
				wp_dequeue_style( 'woocommerce-smallscreen' );
				wp_dequeue_style( 'woocommerce-general' );
				wp_dequeue_style( 'wc-bto-styles' );
				wp_dequeue_script( 'wc-add-to-cart' );
				wp_dequeue_script( 'wc-cart-fragments' );
				wp_dequeue_script( 'woocommerce' );
				wp_dequeue_script( 'jquery-blockui' );
				wp_dequeue_script( 'jquery-placeholder' );
			}
		}
	}
}

/**
 * Init
 */
new Capture_Scripts;
