<?php
/**
 * Single Sections
 *
 * @package Capture
 */

defined( 'WPINC' ) || exit;

/**
 * Single sections
 */
class Capture_Single_Sections extends Capture_Base {
	/**
	 * Single Page Structure
	 */
	public function render() {
		?>
		<article class="<?php capture_article_class(); ?>">
			<?php
			if ( 'mts_nosidebar' !== mts_custom_sidebar() ) {
				$sidebar = capture_custom_sidebar_layout();
			} else {
				$sidebar = 'nosidebar';
			}
			?>
			<div id="content_box" class="<?php echo $sidebar; ?>">
				<?php
				// Elementor 'single' location.
				if ( ! capture_is_elementor( 'single' ) ) {
					if ( have_posts() ) :
						while ( have_posts() ) :
							the_post();
							capture_breadcrumbs();
							?>
						<div id="post-<?php the_ID(); ?>" <?php post_class( 'g post' ); ?>>
							<?php
							// Single post parts ordering.
							if ( ( null !== capture_get_settings( 'mts_single_post_layout' ) ) && is_array( capture_get_settings( 'mts_single_post_layout' ) ) && array_key_exists( 'enabled', capture_get_settings( 'mts_single_post_layout' ) ) ) {
								$single_post_parts = capture_get_settings( 'mts_single_post_layout' )['enabled'];
							} else {
								$single_post_parts = [
									'content'   => 'content',
									'tags'      => 'tags',
									'author'    => 'author',
									'related'   => 'related',
									'subscribe' => 'subscribe',
								];
							}

							foreach ( $single_post_parts as $part => $label ) {
								switch ( $part ) {
									// Content area.
									case 'content':
										capture()->single_sections->single_post();
										break;

									// Content area.
									case 'tags':
										echo '<div class="social-tags">';
										capture_post_tags( '<div class="tags"><div class="tagtext">' . esc_html__( 'Tags', 'capture' ) . '</div>', '' );
										capture()->single_sections->single_post_social_icons();
										echo '</div>';
										break;

									// Author box.
									case 'author':
										capture()->single_sections->single_author_section();
										break;

									// Related Posts.
									case 'related':
										if ( 'default' === capture_get_settings( 'related_posts_position' ) ) {
											capture_related_posts();
										}
										break;

									// Subscribe box.
									case 'subscribe':
										capture()->single_sections->single_subscribe_box();
										break;
								}
							}
							?>
						</div><!--.g post-->
							<?php
							// Comment area.
							comments_template( '', true );

					endwhile;
						wp_reset_postdata();
				endif; /* end loop */
				}
				?>
			</div>
		</article>
		<?php
	}

	/**
	 * Single Post Structure
	 */
	public function single_post() {
		?>
		<div class="single_post">

			<?php

			capture_action( 'single_post_header_thumb' );
			?>

			<div class="post-single-content box mark-links entry-content">

				<?php
				$this->single_post_ads( 'above' );

				$this->single_post_content();

				$this->single_post_pagination();

				$this->single_post_ads( 'below' );

				?>

			</div><!--.post-single-content-->

		</div><!--.single_post-->
		<?php
	}

	/**
	 * Single content
	 */
	public function single_post_content() {
		echo '<div class="thecontent">';
			the_content();
		echo '</div>';
	}

	/**
	 * Single post pagination
	 */
	public function single_post_pagination() {
		// Single Post Pagination.
		$args = [
			'before'           => '<div class="pagination">',
			'after'            => '</div>',
			'link_before'      => '<span class="current"><span class="currenttext">',
			'link_after'       => '</span></span>',
			'next_or_number'   => 'next_and_number',
			'nextpagelink'     => '<i class="fa fa-angle-right"></i>',
			'previouspagelink' => '<i class="fa fa-angle-left"></i>',
			'pagelink'         => '%',
			'echo'             => 1,
		];
		wp_link_pages( $args );
	}

	/**
	 * Author Structure
	 */
	public function single_author_section() {
		?>
		<div class="postauthor">
			<?php
			// Author box title.
			$author_title = capture_get_settings( 'author_box_title' );
			// Author gravatar.
			if ( capture_get_settings( 'author_box_image' ) && function_exists( 'get_avatar' ) ) {
				echo get_avatar( get_the_author_meta( 'email' ), '118' ); // Gravatar size.
			}
			?>
			<div class="postauthor-content">
				<?php
				if ( $author_title ) {
					echo '<h4>' . esc_attr( $author_title ) . '</h4>';
				}
				?>
				<h5 class="vcard author">
					<a href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ); ?>" class="fn">
						<?php the_author_meta( 'display_name' ); ?>
					</a>
				</h5>
				<p><?php the_author_meta( 'description' ); ?></p>
				<?php
				if ( capture_get_settings( 'authorbox_social_share' ) ) {
					$userid      = get_current_user_id();
					$facebook    = get_the_author_meta( 'facebook', $userid );
					$twitter     = get_the_author_meta( 'twitter', $userid );
					$instagram   = get_the_author_meta( 'instagram', $userid );
					$pinterest   = get_the_author_meta( 'pinterest', $userid );
					$stumbleupon = get_the_author_meta( 'stumbleupon', $userid );
					$linkedin    = get_the_author_meta( 'linkedin', $userid );

					if ( ! empty( $facebook ) || ! empty( $twitter ) || ! empty( $instagram ) || ! empty( $pinterest ) || ! empty( $stumbleupon ) || ! empty( $linkedin ) ) {
						echo '<div class="author-social clearfix">';
						if ( ! empty( $facebook ) ) {
							echo '<a href="' . esc_url( $facebook ) . '" class="facebook"><i class="fa fa-facebook-official"></i></a>';
						}
						if ( ! empty( $twitter ) ) {
							echo '<a href="' . esc_url( $twitter ) . '" class="twitter"><i class="fa fa-twitter"></i></a>';
						}
						if ( ! empty( $instagram ) ) {
							echo '<a href="' . esc_url( $instagram ) . '" class="instagram"><i class="fa fa-instagram"></i></a>';
						}
						if ( ! empty( $pinterest ) ) {
							echo '<a href="' . esc_url( $pinterest ) . '" class="pinterest"><i class="fa fa-pinterest"></i></a>';
						}
						if ( ! empty( $stumbleupon ) ) {
							echo '<a href="' . esc_url( $stumbleupon ) . '" class="stumble"><i class="fa fa-stumbleupon"></i></a>';
						}
						if ( ! empty( $linkedin ) ) {
							echo '<a href="' . esc_url( $linkedin ) . '" class="linkedin"><i class="fa fa-linkedin"></i></a>';
						}
						echo '</div>';
					}
				}
				?>
			</div>
		</div>
		<?php
	}

	/**
	 * Subscribe Box
	 */
	public function single_subscribe_box() {
		if ( is_active_sidebar( 'single-subscribe' ) ) {
			?>
			<div class="single-subscribe clear">
				<?php dynamic_sidebar( 'single-subscribe' ); ?>
			</div>
			<?php
		}
	}

	/**
	 * Post Ads
	 */
	public function single_post_ads( $location ) {
		// Above Content Ad Code.
		if ( ! empty( capture_get_settings( 'mts_posttop_adcode' ) ) && 'above' == $location ) {
			$toptime = ! empty( capture_get_settings( 'mts_posttop_adcode_time' ) ) ? capture_get_settings( 'mts_posttop_adcode_time' ) : '0';
			if ( strcmp( date( 'Y-m-d', strtotime( -$toptime . ' day' ) ), get_the_time( 'Y-m-d' ) ) >= 0 ) {
				?>
				<div class="topad">
					<?php echo do_shortcode( capture_get_settings( 'mts_posttop_adcode' ) ); ?>
				</div>
				<?php
			}
		}
		// Below Content Ad Code.
		if ( ! empty( capture_get_settings( 'mts_postend_adcode' ) ) && 'below' == $location ) {
			$endtime = ! empty( capture_get_settings( 'mts_postend_adcode_time' ) ) ? capture_get_settings( 'mts_postend_adcode_time' ) : '0';
			if ( strcmp( date( 'Y-m-d', strtotime( -$endtime . ' day' ) ), get_the_time( 'Y-m-d' ) ) >= 0 ) {
				?>
				<div class="bottomad">
					<?php echo do_shortcode( capture_get_settings( 'mts_postend_adcode' ) ); ?>
				</div>
				<?php
			}
		}
	}

	/**
	 * Single Post Social Icons
	 */
	public function single_post_social_icons() {
		$position = capture_get_settings( 'mts_social_button_position' );
		if ( empty( $position ) ) {
			return;
		}
		// Social Share icons above content.
		if ( 'below' === $position ) {
			echo '<div class="share-wrap">';
				echo '<div class="share-text">' . esc_attr__( 'Share this', 'capture' ) . '</div>';
				capture_social_buttons( 'default' );
			echo '</div>';
		}
		// Social Share icons floating.
		if ( 'floating' === $position ) {
			capture_social_buttons();
		}
	}

}

// Init.
new Capture_Single_Sections();
