<?php
/**
 * Advanced Tab
 *
 * @package Capture
 */

$menus['advanced'] = [
	'icon'  => 'fa-puzzle-piece',
	'title' => esc_html__( 'Advanced', 'capture' ),
];

$menus['advanced']['child'] = [
	'code-fields'    => [ 'title' => esc_html__( 'Code Fields (Tracking etc.)', 'capture' ) ],
	'code-css'       => [ 'title' => esc_html__( 'Custom CSS', 'capture' ) ],
	'theme-features' => [ 'title' => esc_html__( 'Theme Features', 'capture' ) ],
	'dynamic-css'    => [ 'title' => esc_html__( 'Dynamic CSS', 'capture' ) ],
];

/**
 * Code fields
 */
$sections['code-fields'] = [

	[
		'id'       => 'mts_header_code',
		'type'     => 'ace_editor',
		'mode'     => 'html',
		'title'    => esc_html__( 'Before &lt;/head&gt;', 'capture' ),
		'sub_desc' => wp_kses( __( 'Enter the code which you need to place <strong>before closing &lt;/head&gt; tag</strong>. (ex: Google Webmaster Tools verification, Bing Webmaster Center, BuySellAds Script, Alexa verification etc.)', 'capture' ), [ 'strong' => '' ] ),
	],
	[
		'id'       => 'mts_analytics_code',
		'type'     => 'ace_editor',
		'mode'     => 'html',
		'title'    => esc_html__( 'Footer Code', 'capture' ),
		'sub_desc' => wp_kses( __( 'Enter the codes which you need to place in your footer. <strong>(ex: Google Analytics, Clicky, STATCOUNTER, Woopra, Histats, etc.)</strong>.', 'capture' ), [ 'strong' => '' ] ),
	],
];

/**
 * Custom CSS
 */
$sections['code-css'] = [

	[
		'id'       => 'mts_custom_css',
		'type'     => 'ace_editor',
		'mode'     => 'css',
		'title'    => esc_html__( 'Custom CSS', 'capture' ),
		'sub_desc' => esc_html__( 'You can enter custom CSS code here to further customize your theme. This will override the default CSS used on your site.', 'capture' ),
		'args'     => [
			'minLines' => 40,
			'maxLines' => 70,
		],
	],
];

/**
 * Theme Features
 */
$sections['theme-features'] = [

	[
		'id'       => 'retina_images',
		'type'     => 'switch',
		'title'    => esc_html__( 'Retina Images', 'capture' ),
		'sub_desc' => esc_html__( 'Use this button to enable/disable automatic creation of retina images.', 'capture' ),
		'std'      => '1',
	],

	[
		'id'       => 'images_responsive',
		'type'     => 'switch',
		'title'    => esc_html__( 'Responsive Images', 'capture' ),
		'sub_desc' => esc_html__( 'Turn on for images to change size responsively.', 'capture' ),
		'std'      => '0',
	],

	[
		'id'       => 'status_opengraph',
		'type'     => 'switch',
		'title'    => esc_html__( 'Open Graph Meta Tags', 'capture' ),
		'sub_desc' => esc_html__( 'Turn on to enable open graph meta tags which is mainly used when sharing pages on social networking sites like Facebook.', 'capture' ),
		'std'      => '1',
	],
];

/**
 * Dynamic CSS
 */
$sections['dynamic-css'] = [

	[
		'id'       => 'dynamic_css_compiler',
		'type'     => 'switch',
		'title'    => esc_html__( 'CSS Compiler', 'capture' ),
		'sub_desc' => esc_html__( 'Turn on to compile the dynamic CSS into a file. A separate file will be created for each of your pages & posts inside of the uploads/capture-styles folder.', 'capture' ),
		'std'      => '1',
	],

	[
		'id'         => 'dynamic_css_db_caching',
		'type'       => 'switch',
		'title'      => esc_html__( 'Database Caching for Dynamic CSS', 'capture' ),
		'sub_desc'   => esc_html__( 'Turn on to enable caching the dynamic CSS in your database.', 'capture' ),
		'std'        => '0',
		'dependency' => [
			[
				'field'      => 'dynamic_css_compiler',
				'value'      => '0',
				'comparison' => '==',
			],
		],
	],

	[
		'id'       => 'cache_server_ip',
		'type'     => 'text',
		'title'    => esc_html__( 'Cache Server IP', 'capture' ),
		'sub_desc' => esc_html__( 'For unique cases where you are using cloud flare and a cache server, ex: varnish cache. Enter your cache server IP to clear the theme options dynamic CSS cache. Consult with your server admin for help.', 'capture' ),
	],
];
