<?php
/**
 * HomePage Pagination
 *
 * @package Capture
 */

$menus['blog-pagination'] = [
	'icon'  => 'fa-ellipsis-h',
	'title' => esc_html__( 'Pagination', 'capture' ),
	'desc'  => esc_html__( 'From here, you can control the elements of pagination.', 'capture' ),
];

// Dependency check - Default and Numbered pagination.
$default_pagination_dependency = [
	'relation' => 'and',
	[
		'field'      => 'mts_pagenavigation_type',
		'value'      => '2',
		'comparison' => '!=',
	],
	[
		'field'      => 'mts_pagenavigation_type',
		'value'      => '3',
		'comparison' => '!=',
	],
];

// Dependency check the load more button.
$loadmore_button_dependency = [
	'relation' => 'and',
	[
		'field'      => 'mts_pagenavigation_type',
		'value'      => '2',
		'comparison' => '==',
	],
];

$sections['blog-pagination'] = [

	[
		'id'       => 'mts_pagenavigation_type',
		'type'     => 'radio',
		'title'    => esc_html__( 'Pagination Type', 'capture' ),
		'sub_desc' => esc_html__( 'Select pagination type.', 'capture' ),
		'options'  => [
			'0' => esc_html__( 'Default (Next / Previous)', 'capture' ),
			'1' => esc_html__( 'Numbered (1 2 3 4...)', 'capture' ),
			'2' => esc_html__( 'AJAX (Load More Button)', 'capture' ),
			'3' => esc_html__( 'AJAX (Auto Infinite Scroll)', 'capture' ),
		],
		'std'      => '1',
	],

	[
		'id'         => 'pagenavigation_alignment',
		'type'       => 'button_set',
		'title'      => esc_html__( 'Pagination Alignment', 'capture' ),
		'sub_desc'   => esc_html__( 'Choose pagination alignment from here.', 'capture' ),
		'options'    => [
			'left'   => esc_html__( 'Left', 'capture' ),
			'center' => esc_html__( 'Center', 'capture' ),
			'right'  => esc_html__( 'Right', 'capture' ),
		],
		'std'        => 'center',
		'dependency' => $default_pagination_dependency,
	],

	[
		'id'         => 'load_more_alignment',
		'type'       => 'button_set',
		'title'      => esc_html__( 'Load More Alignment', 'capture' ),
		'sub_desc'   => esc_html__( 'Choose the load more alignment from here.', 'capture' ),
		'options'    => [
			'left'   => esc_html__( 'Left', 'capture' ),
			'center' => esc_html__( 'Center', 'capture' ),
			'right'  => esc_html__( 'Right', 'capture' ),
			'full'   => esc_html__( 'Full Width', 'capture' ),
		],
		'std'        => 'center',
		'dependency' => $loadmore_button_dependency,
	],
	[
		'id'         => 'mts_pagenavigation_bgcolor',
		'type'       => 'color',
		'title'      => esc_html__( 'Pagination background color', 'capture' ),
		'sub_desc'   => esc_html__( 'Select pagination background color.', 'capture' ),
		'std'        => '#ffffff',
		'dependency' => $default_pagination_dependency,
	],
	[
		'id'         => 'load_more_bgcolor',
		'type'       => 'color',
		'title'      => esc_html__( 'Load More background color', 'capture' ),
		'sub_desc'   => esc_html__( 'Select background color for load more button.', 'capture' ),
		'std'        => '#000000',
		'dependency' => $loadmore_button_dependency,
	],
	[
		'id'         => 'mts_pagenavigation_hover_bgcolor',
		'type'       => 'color',
		'title'      => esc_html__( 'Pagination background hover color', 'capture' ),
		'sub_desc'   => esc_html__( 'Select pagination background hover color.', 'capture' ),
		'std'        => '#000000',
		'dependency' => $default_pagination_dependency,
	],
	[
		'id'         => 'load_more_hover_bgcolor',
		'type'       => 'color',
		'title'      => esc_html__( 'Load More background hover color', 'capture' ),
		'sub_desc'   => esc_html__( 'Select background hover color for load more button.', 'capture' ),
		'std'        => '#969696',
		'dependency' => $loadmore_button_dependency,
	],
	[
		'id'         => 'mts_pagenavigation_color',
		'type'       => 'color',
		'title'      => esc_html__( 'Pagination color', 'capture' ),
		'sub_desc'   => esc_html__( 'Select pagination color.', 'capture' ),
		'std'        => '#969696',
		'dependency' => $default_pagination_dependency,
	],
	[
		'id'         => 'load_more_color',
		'type'       => 'color',
		'title'      => esc_html__( 'Load More color', 'capture' ),
		'sub_desc'   => esc_html__( 'Select color for load more button.', 'capture' ),
		'std'        => '#ffffff',
		'dependency' => $loadmore_button_dependency,
	],
	[
		'id'         => 'mts_pagenavigation_hover_color',
		'type'       => 'color',
		'title'      => esc_html__( 'Pagination hover color', 'capture' ),
		'sub_desc'   => esc_html__( 'Select pagination hover color.', 'capture' ),
		'std'        => '#ffffff',
		'dependency' => $default_pagination_dependency,
	],
	[
		'id'         => 'load_more_hover_color',
		'type'       => 'color',
		'title'      => esc_html__( 'Load More hover color', 'capture' ),
		'sub_desc'   => esc_html__( 'Select hover color for load more button.', 'capture' ),
		'std'        => '#ffffff',
		'dependency' => $loadmore_button_dependency,
	],
	[
		'id'       => 'mts_pagenavigation_margin',
		'type'     => 'margin',
		'title'    => esc_html__( 'Pagination Margin', 'capture' ),
		'sub_desc' => esc_html__( 'Update pagination margin from here.', 'capture' ),
		'std'      => [
			'top'    => '0',
			'right'  => '5px',
			'bottom' => '10px',
			'left'   => '3px',
		],
	],
	[
		'id'         => 'mts_pagenavigation_padding',
		'type'       => 'margin',
		'title'      => esc_html__( 'Pagination Padding', 'capture' ),
		'sub_desc'   => esc_html__( 'Update pagination padding from here.', 'capture' ),
		'std'        => [
			'top'    => '15px',
			'right'  => '4px',
			'bottom' => '11px',
			'left'   => '4px',
		],
		'dependency' => $default_pagination_dependency,
	],
	[
		'id'         => 'load_more_padding',
		'type'       => 'margin',
		'title'      => esc_html__( 'Load More Padding', 'capture' ),
		'sub_desc'   => esc_html__( 'Update padding for load more button from here.', 'capture' ),
		'std'        => [
			'top'    => '15px',
			'right'  => '35px',
			'bottom' => '17px',
			'left'   => '40px',
		],
		'dependency' => $loadmore_button_dependency,
	],
	[
		'id'         => 'mts_pagenavigation_border_radius',
		'type'       => 'text',
		'class'      => 'small-text',
		'title'      => esc_html__( 'Pagination border radius', 'capture' ),
		'sub_desc'   => esc_html__( 'Update pagination border radius in px.', 'capture' ),
		'std'        => '50',
		'args'       => [ 'type' => 'number' ],
		'dependency' => $default_pagination_dependency,
	],
	[
		'id'         => 'load_more_border_radius',
		'type'       => 'text',
		'class'      => 'small-text',
		'title'      => esc_html__( 'Load More border radius', 'capture' ),
		'sub_desc'   => esc_html__( 'Update Load More border radius in px.', 'capture' ),
		'std'        => '28',
		'args'       => [ 'type' => 'number' ],
		'dependency' => $loadmore_button_dependency,
	],
	[
		'id'         => 'pagenavigation_border',
		'type'       => 'border',
		'title'      => esc_html__( 'Border', 'capture' ),
		'sub_desc'   => esc_html__( 'Select border', 'capture' ),
		'std'        => [
			'direction' => 'all',
			'size'      => '1',
			'style'     => 'solid',
			'color'     => '#969696',
		],
		'dependency' => $default_pagination_dependency,
	],
	[
		'id'         => 'load_more_border',
		'type'       => 'border',
		'title'      => esc_html__( 'Border', 'capture' ),
		'sub_desc'   => esc_html__( 'Select border', 'capture' ),
		'dependency' => $loadmore_button_dependency,
	],
	[
		'id'         => 'pagination_font',
		'type'       => 'typography',
		'title'      => esc_html__( 'Pagination Font', 'capture' ),
		'color'      => false,
		'std'        => [
			'preview-text'  => 'Pagination Font',
			'preview-color' => 'light',
			'font-family'   => 'Spartan',
			'font-weight'   => '600',
			'font-size'     => '12px',
			'margin-top'    => capture_px2rem( '-32px' ),
			'margin-bottom' => capture_px2rem( '16px' ),
			'css-selectors' => '.pagination, .woocommerce-pagination',
		],
		'dependency' => $default_pagination_dependency,
	],
	[
		'id'         => 'loadmore_font',
		'type'       => 'typography',
		'title'      => esc_html__( 'Load More Font', 'capture' ),
		'color'      => false,
		'std'        => [
			'preview-text'   => 'Load More Font',
			'preview-color'  => 'dark',
			'font-family'    => 'Spartan',
			'font-weight'    => '600',
			'font-size'      => '12px',
			'margin-top'     => capture_px2rem( '-32px' ),
			'margin-bottom'  => capture_px2rem( '16px' ),
			'letter-spacing' => capture_letter_spacing( 12, 167 ),
			'additional-css' => 'text-transform: uppercase;',
			'css-selectors'  => '#load-posts a',
		],
		'dependency' => $loadmore_button_dependency,
	],

];
