<?php
/**
 * HomePage Posts
 *
 * @package Capture
 */

$features = capture_get_settings( 'featured_categories' );
if ( empty( $features ) ) {
	return;
}
foreach ( $features as $feature ) :
	$title        = isset( $feature['mts_featured_title'] ) ? $feature['mts_featured_title'] : 'No Title';
	$posts_layout = isset( $feature['blog_layout'] ) ? $feature['blog_layout'] : '';
	if ( 'layout-default' === $posts_layout ) {
		$posts_layout = 'default';
	}
	$unique_id = isset( $feature['unique_id'] ) ? $feature['unique_id'] : '';

	$menus['blog']['child'][ 'blog-' . $unique_id ] = [
		'title' => $title,
		// translators: description.
		'desc'  => sprintf( wp_kses_post( __( 'From here, you can control the elements of %s', 'capture' ) ), $title ),
	];

	// Dependency check that Title is enable.
	$post_title_dependency = [
		'field'      => 'featured_category_title_' . $unique_id,
		'value'      => '1',
		'comparison' => '==',
	];

	// Dependency check that excerpt is enable.
	$post_excerpt_dependency = [
		'relation' => 'and',
		[
			'field'      => 'post_excerpt_' . $unique_id,
			'value'      => '1',
			'comparison' => '==',
		],
	];

	$readmore = [
		'relation' => 'and',
		[
			'field'      => 'readmore_' . $unique_id,
			'value'      => '1',
			'comparison' => '==',
		],
	];

	$sections[ 'blog-' . $unique_id ] = [

		/**
		 * Layout Default Settings
		 *
		 * @package Capture
		 */

		// Section Title.
		( 'default' === $posts_layout ) ? [
			'id'    => 'post_title_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Section Title', 'capture' ),
		] : null,

		( 'default' === $posts_layout ) ? [
			'id'       => 'featured_category_title_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Title', 'capture' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide title of post container.', 'capture' ),
			'std'      => '0',
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'    => 'featured_category_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Section Title Typography', 'capture' ),
			'std'   => [
				'preview-text'   => 'Title Font',
				'preview-color'  => 'light',
				'font-family'    => 'Spartan',
				'font-weight'    => '700',
				'font-size'      => capture_px2rem( '24px' ),
				'line-height'    => '1.2',
				'color'          => '#000000',
				'letter-spacing' => capture_letter_spacing( 24, 16 ),
				'css-selectors'  => '.title-container.title-id-' . $unique_id . ' h3.featured-category-title',
			],
			[
				'relation' => 'and',
				$post_title_dependency,
			],
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'       => 'featured_category_title_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Post Title Margin', 'capture' ),
			'sub_desc' => esc_html__( 'Set section title margin from here.', 'capture' ),
			'std'      => [
				'top'    => '0',
				'right'  => '0',
				'bottom' => capture_px2rem( '30px' ),
				'left'   => '0',
			],
			[
				'relation' => 'and',
				$post_title_dependency,
			],
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'       => 'featured_category_title_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Post Title Padding', 'capture' ),
			'sub_desc' => esc_html__( 'Set section title padding from here.', 'capture' ),
			'std'      => [
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			],
			[
				'relation' => 'and',
				$post_title_dependency,
			],
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'       => 'post_title_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'capture' ),
			'sub_desc' => esc_html__( 'Select border', 'capture' ),
			[
				'relation' => 'and',
				$post_title_dependency,
			],
		] : null,
		// Post Alignment.
		( 'default' === $posts_layout ) ? [
			'id'    => 'post_content_alignment_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Alignment', 'capture' ),
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'       => 'post_alignment_' . $unique_id,
			'type'     => 'button_set',
			'title'    => esc_html__( 'Post Alignment', 'capture' ),
			'sub_desc' => esc_html__( 'Choose the post alignment', 'capture' ),
			'options'  => [
				'left'   => esc_html__( 'Left', 'capture' ),
				'center' => esc_html__( 'Center', 'capture' ),
				'right'  => esc_html__( 'Right', 'capture' ),
			],
			'std'      => 'center',
		] : null,
		// Meta info.
		( 'default' === $posts_layout ) ? [
			'id'    => 'post_meta_info_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Meta Info', 'capture' ),
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'       => 'mts_home_headline_meta_info' . $unique_id,
			'type'     => 'layout2',
			// translators: title.
			'title'    => sprintf( wp_kses_post( __( '%s Meta Info', 'capture' ) ), $title ),
			// translators: description.
			'sub_desc' => sprintf( wp_kses_post( __( 'Organize how you want the post meta info to appear on %s', 'capture' ) ), $title ),
			'options'  => [
				'enabled'  => [
					'date'     => [
						'label'     => esc_html__( 'Date', 'capture' ),
						'subfields' => [
							[
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'capture' ),
							],
						],
					],
					'category' => [
						'label'     => esc_html__( 'Categories', 'capture' ),
						'subfields' => [
							[
								'id'    => 'mts_meta_info_category_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'capture' ),
							],
						],
					],
				],
				'disabled' => [
					'author'  => [
						'label'     => __( 'Author Name', 'capture' ),
						'subfields' => [
							[
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'capture' ),
							],
						],
					],
					'comment' => [
						'label'     => esc_html__( 'Comment Count', 'capture' ),
						'subfields' => [
							[
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'capture' ),
							],
						],
					],
				],
			],
			'std'      => [
				'enabled'  => [
					'date'     => [
						'label'     => esc_html__( 'Date', 'capture' ),
						'subfields' => [
							[
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'capture' ),
							],
						],
					],
					'category' => [
						'label'     => esc_html__( 'Categories', 'capture' ),
						'subfields' => [
							[
								'id'    => 'mts_meta_info_category_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'capture' ),
							],
						],
					],
				],
				'disabled' => [
					'author'  => [
						'label'     => __( 'Author Name', 'capture' ),
						'subfields' => [
							[
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'capture' ),
							],
						],
					],
					'comment' => [
						'label'     => esc_html__( 'Comment Count', 'capture' ),
						'subfields' => [
							[
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'capture' ),
							],
						],
					],
				],
			],
		] : null,

		( 'default' === $posts_layout ) ? [
			'id'    => 'meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Meta Info Typography', 'capture' ),
			'std'   => [
				'preview-text'   => 'Post Meta Info Font',
				'preview-color'  => 'light',
				'font-family'    => 'Spartan',
				'font-weight'    => '700',
				'font-size'      => '12px',
				'color'          => '#969696',
				'margin-top'     => capture_px2rem( '16px' ),
				'letter-spacing' => capture_letter_spacing( 12, 167 ),
				'additional-css' => 'text-transform: uppercase;',
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .post-info',
			],
		] : null,
		// Read More Button.
		( 'default' === $posts_layout ) ? [
			'id'    => 'post_readmore_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Read More Button', 'capture' ),
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'       => 'readmore_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Enable/Disable Read More', 'capture' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide Read More.', 'capture' ),
			'std'      => '1',
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'         => 'readmore_text_' . $unique_id,
			'type'       => 'text',
			'title'      => esc_html__( 'Button Text', 'capture' ),
			'std'        => 'Read Story',
			'dependency' => $readmore,
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'         => 'readmore_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Button Font', 'capture' ),
			'std'        => [
				'preview-text'   => 'Read Story Font',
				'preview-color'  => 'light',
				'font-family'    => 'Spartan',
				'font-weight'    => '700',
				'font-size'      => '12px',
				'color'          => '#000000',
				'line-height'    => '1.5',
				'margin-top'     => capture_px2rem( '16px' ),
				'letter-spacing' => capture_letter_spacing( 12, 167 ),
				'additional-css' => 'text-transform: uppercase;',
				'css-selectors'  => '.layout-' . $unique_id . ' .readMore a',
			],
			'dependency' => $readmore,
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'         => 'readmore_bg_color_' . $unique_id,
			'type'       => 'color',
			'title'      => esc_html__( 'Button Background Color', 'capture' ),
			'std'        => '#ffffff',
			'dependency' => $readmore,
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'         => 'readmore_border_' . $unique_id,
			'type'       => 'border',
			'title'      => esc_html__( 'Button Border', 'capture' ),
			'sub_desc'   => esc_html__( 'Select border.', 'capture' ),
			'std'        => [
				'direction' => 'all',
				'size'      => '1',
				'style'     => 'solid',
				'color'     => '#000000',
			],
			'dependency' => $readmore,
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'         => 'readmore_bg_hover_color_' . $unique_id,
			'type'       => 'color',
			'title'      => esc_html__( 'Button Background Hover Color', 'capture' ),
			'std'        => '#ffffff',
			'dependency' => $readmore,
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'         => 'readmore_hover_color_' . $unique_id,
			'type'       => 'color',
			'title'      => esc_html__( 'Button Hover Color', 'capture' ),
			'std'        => '#969696',
			'dependency' => $readmore,
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'         => 'readmore_border_hover_color_' . $unique_id,
			'type'       => 'color',
			'title'      => esc_html__( 'Button Border Hover Color', 'capture' ),
			'std'        => '#969696',
			'dependency' => $readmore,
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'         => 'readmore_btn_padding_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Button Padding', 'capture' ),
			'sub_desc'   => esc_html__( 'Set Posts button padding from here.', 'capture' ),
			'std'        => [
				'top'    => '20px',
				'right'  => '40px',
				'bottom' => '16px',
				'left'   => '40px',
			],
			'dependency' => $readmore,
		] : null,
		// Post Container.
		( 'default' === $posts_layout ) ? [
			'id'    => 'post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'capture' ),
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'       => 'post_background_' . $unique_id,
			'type'     => 'background',
			'title'    => esc_html__( 'Post Background Color', 'capture' ),
			'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'capture' ),
			'options'  => [
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => [],       // false to disable, array of options to override default ( optional ).
				'attachment'    => [],       // false to disable, array of options to override default ( optional ).
				'position'      => [],       // false to disable, array of options to override default ( optional ).
				'size'          => [],       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => [],       // false to disable, array of options to override default ( optional ).
			],
			'std'      => [
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => [
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				],
				'parallax'      => '0',
			],
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'capture' ),
			'sub_desc' => esc_html__( 'Select border', 'capture' ),
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'       => 'post_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'capture' ),
			'sub_desc' => esc_html__( 'Post margin.', 'capture' ),
			'left'     => false,
			'right'    => false,
			'std'      => [
				'top'    => '0',
				'bottom' => '0',
			],
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'       => 'post_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'capture' ),
			'sub_desc' => esc_html__( 'Post padding.', 'capture' ),
			'std'      => [
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			],
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'    => 'post_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Title Font', 'capture' ),
			'std'   => [
				'preview-text'   => 'Post Title Font',
				'preview-color'  => 'light',
				'font-family'    => 'Spartan',
				'font-weight'    => '700',
				'font-size'      => '20px',
				'line-height'    => '1.2',
				'margin-top'     => capture_px2rem( '8px' ),
				'margin-bottom'  => '5px',
				'color'          => '#000000',
				'letter-spacing' => capture_letter_spacing( 20, -16 ),
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .title a',
			],
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'       => 'post_excerpt_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show Post Excerpts', 'capture' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide post excerpt.', 'capture' ),
			'std'      => '1',
		] : null,
		( 'default' === $posts_layout ) ? [
			'id'         => 'post_excerpt_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Post Excerpt Font', 'capture' ),
			'std'        => [
				'preview-text'  => 'Post Excerpt Font',
				'preview-color' => 'light',
				'font-family'   => 'Spartan',
				'font-weight'   => '400',
				'font-size'     => '14px',
				'line-height'   => capture_line_height( 14, 24 ),
				'color'         => '#000000',
				'margin-bottom' => capture_px2rem( 15 ),
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .front-view-content',
			],
			'dependency' => $post_excerpt_dependency,
		] : null,

		/**
		 * Layout 1 Settings
		 *
		 * @package Capture
		 */

		( 'layout-1' === $posts_layout ) ? [
			'id'    => 'post_title_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Section Title', 'capture' ),
		] : null,

		( 'layout-1' === $posts_layout ) ? [
			'id'       => 'featured_category_title_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Title', 'capture' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide title of post container.', 'capture' ),
			'std'      => '0',
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'    => 'featured_category_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Section Title Typography', 'capture' ),
			'std'   => [
				'preview-text'   => 'Title Font',
				'preview-color'  => 'light',
				'font-family'    => 'Spartan',
				'font-weight'    => '700',
				'font-size'      => capture_px2rem( '24px' ),
				'line-height'    => '1.2',
				'color'          => '#000000',
				'letter-spacing' => capture_letter_spacing( 24, 16 ),
				'css-selectors'  => '.title-container.title-id-' . $unique_id . ' h3.featured-category-title',
			],
			[
				'relation' => 'and',
				$post_title_dependency,
			],
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'       => 'featured_category_title_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Post Title Margin', 'capture' ),
			'sub_desc' => esc_html__( 'Set section title margin from here.', 'capture' ),
			'std'      => [
				'top'    => '0',
				'right'  => '0',
				'bottom' => capture_px2rem( '30px' ),
				'left'   => '0',
			],
			[
				'relation' => 'and',
				$post_title_dependency,
			],
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'       => 'featured_category_title_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Post Title Padding', 'capture' ),
			'sub_desc' => esc_html__( 'Set section title padding from here.', 'capture' ),
			'std'      => [
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			],
			[
				'relation' => 'and',
				$post_title_dependency,
			],
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'       => 'post_title_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'capture' ),
			'sub_desc' => esc_html__( 'Select border', 'capture' ),
			[
				'relation' => 'and',
				$post_title_dependency,
			],
		] : null,
		// Post Alignment.
		( 'layout-1' === $posts_layout ) ? [
			'id'    => 'post_content_alignment_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Alignment', 'capture' ),
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'       => 'post_alignment_' . $unique_id,
			'type'     => 'button_set',
			'title'    => esc_html__( 'Post Alignment', 'capture' ),
			'sub_desc' => esc_html__( 'Choose the post alignment', 'capture' ),
			'options'  => [
				'left'   => esc_html__( 'Left', 'capture' ),
				'center' => esc_html__( 'Center', 'capture' ),
				'right'  => esc_html__( 'Right', 'capture' ),
			],
			'std'      => 'center',
		] : null,
		// Meta info.
		( 'layout-1' === $posts_layout ) ? [
			'id'    => 'post_meta_info_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Meta Info', 'capture' ),
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'       => 'mts_home_headline_meta_info' . $unique_id,
			'type'     => 'layout2',
			// translators: title.
			'title'    => sprintf( wp_kses_post( __( '%s Meta Info', 'capture' ) ), $title ),
			// translators: description.
			'sub_desc' => sprintf( wp_kses_post( __( 'Organize how you want the post meta info to appear on %s', 'capture' ) ), $title ),
			'options'  => [
				'enabled'  => [
					'date'     => [
						'label'     => esc_html__( 'Date', 'capture' ),
						'subfields' => [
							[
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'capture' ),
							],
						],
					],
					'category' => [
						'label'     => esc_html__( 'Categories', 'capture' ),
						'subfields' => [
							[
								'id'    => 'mts_meta_info_category_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'capture' ),
							],
						],
					],
				],
				'disabled' => [
					'author'  => [
						'label'     => __( 'Author Name', 'capture' ),
						'subfields' => [
							[
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'capture' ),
							],
						],
					],
					'comment' => [
						'label'     => esc_html__( 'Comment Count', 'capture' ),
						'subfields' => [
							[
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'capture' ),
							],
						],
					],
				],
			],
			'std'      => [
				'enabled'  => [
					'date'     => [
						'label'     => esc_html__( 'Date', 'capture' ),
						'subfields' => [
							[
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'capture' ),
							],
						],
					],
					'category' => [
						'label'     => esc_html__( 'Categories', 'capture' ),
						'subfields' => [
							[
								'id'    => 'mts_meta_info_category_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'capture' ),
							],
						],
					],
				],
				'disabled' => [
					'author'  => [
						'label'     => __( 'Author Name', 'capture' ),
						'subfields' => [
							[
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'capture' ),
							],
						],
					],
					'comment' => [
						'label'     => esc_html__( 'Comment Count', 'capture' ),
						'subfields' => [
							[
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'capture' ),
							],
						],
					],
				],
			],
		] : null,

		( 'layout-1' === $posts_layout ) ? [
			'id'       => 'show_readmore_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show ReadMore', 'capture' ),
			'sub_desc' => esc_html__( 'Show/Hide readmore button from this option.', 'capture' ),
			'std'      => '1',
		] : null,

		( 'layout-1' === $posts_layout ) ? [
			'id'    => 'meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Meta Info Typography', 'capture' ),
			'std'   => [
				'preview-text'   => 'Post Meta Info Font',
				'preview-color'  => 'light',
				'font-family'    => 'Spartan',
				'font-weight'    => '700',
				'font-size'      => '12px',
				'color'          => '#969696',
				'margin-top'     => capture_px2rem( '16px' ),
				'letter-spacing' => capture_letter_spacing( 12, 167 ),
				'additional-css' => 'text-transform: uppercase;',
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .post-info',
			],
		] : null,
		// Read More Button.
		( 'layout-1' === $posts_layout ) ? [
			'id'    => 'post_readmore_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Read More Button', 'capture' ),
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'       => 'readmore_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Enable/Disable Read More', 'capture' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide Read More.', 'capture' ),
			'std'      => '1',
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'         => 'readmore_text_' . $unique_id,
			'type'       => 'text',
			'title'      => esc_html__( 'Button Text', 'capture' ),
			'std'        => 'Read Story',
			'dependency' => $readmore,
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'         => 'readmore_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Button Font', 'capture' ),
			'std'        => [
				'preview-text'   => 'Read Story Font',
				'preview-color'  => 'light',
				'font-family'    => 'Spartan',
				'font-weight'    => '700',
				'font-size'      => '12px',
				'color'          => '#000000',
				'line-height'    => '1.5',
				'margin-top'     => capture_px2rem( '16px' ),
				'letter-spacing' => capture_letter_spacing( 12, 167 ),
				'additional-css' => 'text-transform: uppercase;',
				'css-selectors'  => '.layout-' . $unique_id . ' .readMore a',
			],
			'dependency' => $readmore,
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'         => 'readmore_bg_color_' . $unique_id,
			'type'       => 'color',
			'title'      => esc_html__( 'Button Background Color', 'capture' ),
			'std'        => '#ffffff',
			'dependency' => $readmore,
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'         => 'readmore_border_' . $unique_id,
			'type'       => 'border',
			'title'      => esc_html__( 'Button Border', 'capture' ),
			'sub_desc'   => esc_html__( 'Select border.', 'capture' ),
			'std'        => [
				'direction' => 'all',
				'size'      => '1',
				'style'     => 'solid',
				'color'     => '#000000',
			],
			'dependency' => $readmore,
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'         => 'readmore_bg_hover_color_' . $unique_id,
			'type'       => 'color',
			'title'      => esc_html__( 'Button Background Hover Color', 'capture' ),
			'std'        => '#ffffff',
			'dependency' => $readmore,
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'         => 'readmore_hover_color_' . $unique_id,
			'type'       => 'color',
			'title'      => esc_html__( 'Button Hover Color', 'capture' ),
			'std'        => '#969696',
			'dependency' => $readmore,
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'         => 'readmore_border_hover_color_' . $unique_id,
			'type'       => 'color',
			'title'      => esc_html__( 'Button Border Hover Color', 'capture' ),
			'std'        => '#969696',
			'dependency' => $readmore,
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'         => 'readmore_btn_padding_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Button Padding', 'capture' ),
			'sub_desc'   => esc_html__( 'Set Posts button padding from here.', 'capture' ),
			'std'        => [
				'top'    => '20px',
				'right'  => '40px',
				'bottom' => '16px',
				'left'   => '40px',
			],
			'dependency' => $readmore,
		] : null,
		// Post Container.
		( 'layout-1' === $posts_layout ) ? [
			'id'    => 'post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'capture' ),
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'       => 'post_background_' . $unique_id,
			'type'     => 'background',
			'title'    => esc_html__( 'Post Background Color', 'capture' ),
			'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'capture' ),
			'options'  => [
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => [],       // false to disable, array of options to override default ( optional ).
				'attachment'    => [],       // false to disable, array of options to override default ( optional ).
				'position'      => [],       // false to disable, array of options to override default ( optional ).
				'size'          => [],       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => [],       // false to disable, array of options to override default ( optional ).
			],
			'std'      => [
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => [
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				],
				'parallax'      => '0',
			],
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'capture' ),
			'sub_desc' => esc_html__( 'Select border', 'capture' ),
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'       => 'post_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'capture' ),
			'sub_desc' => esc_html__( 'Post margin.', 'capture' ),
			'left'     => false,
			'right'    => false,
			'std'      => [
				'top'    => capture_px2rem( '50px' ),
				'bottom' => '0',
			],
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'       => 'post_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'capture' ),
			'sub_desc' => esc_html__( 'Post padding.', 'capture' ),
			'std'      => [
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			],
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'    => 'post_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Title Font', 'capture' ),
			'std'   => [
				'preview-text'   => 'Post Title Font',
				'preview-color'  => 'light',
				'font-family'    => 'Spartan',
				'font-weight'    => '700',
				'font-size'      => '18px',
				'line-height'    => '1.2',
				'margin-top'     => capture_px2rem( '8px' ),
				'margin-bottom'  => '5px',
				'color'          => '#000000',
				'letter-spacing' => capture_letter_spacing( 18, -16 ),
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .title a',
			],
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'       => 'post_excerpt_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show Post Excerpts', 'capture' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide post excerpt.', 'capture' ),
			'std'      => '1',
		] : null,
		( 'layout-1' === $posts_layout ) ? [
			'id'         => 'post_excerpt_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Post Excerpt Font', 'capture' ),
			'std'        => [
				'preview-text'  => 'Post Excerpt Font',
				'preview-color' => 'light',
				'font-family'   => 'Spartan',
				'font-weight'   => '400',
				'font-size'     => '14px',
				'line-height'   => capture_line_height( 14, 24 ),
				'color'         => '#000000',
				'margin-bottom' => capture_px2rem( 15 ),
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .front-view-content',
			],
			'dependency' => $post_excerpt_dependency,
		] : null,

		/**
		 * Layout 2 Settings
		 *
		 * @package Capture
		 */

		// Section Title.
		( 'layout-2' === $posts_layout ) ? [
			'id'    => 'post_title_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Section Title', 'capture' ),
		] : null,

		( 'layout-2' === $posts_layout ) ? [
			'id'       => 'featured_category_title_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Title', 'capture' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide title of post container.', 'capture' ),
			'std'      => '0',
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'    => 'featured_category_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Section Title Typography', 'capture' ),
			'std'   => [
				'preview-text'   => 'Title Font',
				'preview-color'  => 'light',
				'font-family'    => 'Spartan',
				'font-weight'    => '700',
				'font-size'      => capture_px2rem( '24px' ),
				'line-height'    => '1.2',
				'color'          => '#000000',
				'letter-spacing' => capture_letter_spacing( 24, 16 ),
				'css-selectors'  => '.title-container.title-id-' . $unique_id . ' h3.featured-category-title',
			],
			[
				'relation' => 'and',
				$post_title_dependency,
			],
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'       => 'featured_category_title_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Post Title Margin', 'capture' ),
			'sub_desc' => esc_html__( 'Set section title margin from here.', 'capture' ),
			'std'      => [
				'top'    => '0',
				'right'  => '0',
				'bottom' => capture_px2rem( '30px' ),
				'left'   => '0',
			],
			[
				'relation' => 'and',
				$post_title_dependency,
			],
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'       => 'featured_category_title_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Post Title Padding', 'capture' ),
			'sub_desc' => esc_html__( 'Set section title padding from here.', 'capture' ),
			'std'      => [
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			],
			[
				'relation' => 'and',
				$post_title_dependency,
			],
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'       => 'post_title_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'capture' ),
			'sub_desc' => esc_html__( 'Select border', 'capture' ),
			[
				'relation' => 'and',
				$post_title_dependency,
			],
		] : null,
		// Post Alignment.
		( 'layout-2' === $posts_layout ) ? [
			'id'    => 'post_content_alignment_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Alignment', 'capture' ),
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'       => 'post_alignment_' . $unique_id,
			'type'     => 'button_set',
			'title'    => esc_html__( 'Post Alignment', 'capture' ),
			'sub_desc' => esc_html__( 'Choose the post alignment', 'capture' ),
			'options'  => [
				'left'   => esc_html__( 'Left', 'capture' ),
				'center' => esc_html__( 'Center', 'capture' ),
				'right'  => esc_html__( 'Right', 'capture' ),
			],
			'std'      => 'center',
		] : null,
		// Meta info.
		( 'layout-2' === $posts_layout ) ? [
			'id'    => 'post_meta_info_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Meta Info', 'capture' ),
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'       => 'mts_home_headline_meta_info' . $unique_id,
			'type'     => 'layout2',
			// translators: title.
			'title'    => sprintf( wp_kses_post( __( '%s Meta Info', 'capture' ) ), $title ),
			// translators: description.
			'sub_desc' => sprintf( wp_kses_post( __( 'Organize how you want the post meta info to appear on %s', 'capture' ) ), $title ),
			'options'  => [
				'enabled'  => [
					'date'     => [
						'label'     => esc_html__( 'Date', 'capture' ),
						'subfields' => [
							[
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'capture' ),
							],
						],
					],
					'category' => [
						'label'     => esc_html__( 'Categories', 'capture' ),
						'subfields' => [
							[
								'id'    => 'mts_meta_info_category_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'capture' ),
							],
						],
					],
				],
				'disabled' => [
					'author'  => [
						'label'     => __( 'Author Name', 'capture' ),
						'subfields' => [
							[
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'capture' ),
							],
						],
					],
					'comment' => [
						'label'     => esc_html__( 'Comment Count', 'capture' ),
						'subfields' => [
							[
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'capture' ),
							],
						],
					],
				],
			],
			'std'      => [
				'enabled'  => [
					'date'     => [
						'label'     => esc_html__( 'Date', 'capture' ),
						'subfields' => [
							[
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'capture' ),
							],
						],
					],
					'category' => [
						'label'     => esc_html__( 'Categories', 'capture' ),
						'subfields' => [
							[
								'id'    => 'mts_meta_info_category_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'capture' ),
							],
						],
					],
				],
				'disabled' => [
					'author'  => [
						'label'     => __( 'Author Name', 'capture' ),
						'subfields' => [
							[
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'capture' ),
							],
						],
					],
					'comment' => [
						'label'     => esc_html__( 'Comment Count', 'capture' ),
						'subfields' => [
							[
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'capture' ),
							],
						],
					],
				],
			],
		] : null,

		( 'layout-2' === $posts_layout ) ? [
			'id'       => 'show_readmore_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show ReadMore', 'capture' ),
			'sub_desc' => esc_html__( 'Show/Hide readmore button from this option.', 'capture' ),
			'std'      => '1',
		] : null,

		( 'layout-2' === $posts_layout ) ? [
			'id'    => 'meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Meta Info Typography', 'capture' ),
			'std'   => [
				'preview-text'   => 'Post Meta Info Font',
				'preview-color'  => 'light',
				'font-family'    => 'Spartan',
				'font-weight'    => '700',
				'font-size'      => '12px',
				'color'          => '#969696',
				'margin-top'     => capture_px2rem( '16px' ),
				'letter-spacing' => capture_letter_spacing( 12, 167 ),
				'additional-css' => 'text-transform: uppercase;',
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .post-info',
			],
		] : null,
		// Read More Button.
		( 'layout-2' === $posts_layout ) ? [
			'id'    => 'post_readmore_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Read More Button', 'capture' ),
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'       => 'readmore_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Enable/Disable Read More', 'capture' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide Read More.', 'capture' ),
			'std'      => '1',
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'         => 'readmore_text_' . $unique_id,
			'type'       => 'text',
			'title'      => esc_html__( 'Button Text', 'capture' ),
			'std'        => 'Read Story',
			'dependency' => $readmore,
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'         => 'readmore_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Button Font', 'capture' ),
			'std'        => [
				'preview-text'   => 'Read Story Font',
				'preview-color'  => 'light',
				'font-family'    => 'Spartan',
				'font-weight'    => '700',
				'font-size'      => '12px',
				'color'          => '#000000',
				'line-height'    => '1.5',
				'margin-top'     => capture_px2rem( '16px' ),
				'letter-spacing' => capture_letter_spacing( 12, 167 ),
				'additional-css' => 'text-transform: uppercase;',
				'css-selectors'  => '.layout-' . $unique_id . ' .readMore a',
			],
			'dependency' => $readmore,
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'         => 'readmore_bg_color_' . $unique_id,
			'type'       => 'color',
			'title'      => esc_html__( 'Button Background Color', 'capture' ),
			'std'        => '#ffffff',
			'dependency' => $readmore,
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'         => 'readmore_border_' . $unique_id,
			'type'       => 'border',
			'title'      => esc_html__( 'Button Border', 'capture' ),
			'sub_desc'   => esc_html__( 'Select border.', 'capture' ),
			'std'        => [
				'direction' => 'all',
				'size'      => '1',
				'style'     => 'solid',
				'color'     => '#000000',
			],
			'dependency' => $readmore,
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'         => 'readmore_bg_hover_color_' . $unique_id,
			'type'       => 'color',
			'title'      => esc_html__( 'Button Background Hover Color', 'capture' ),
			'std'        => '#ffffff',
			'dependency' => $readmore,
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'         => 'readmore_hover_color_' . $unique_id,
			'type'       => 'color',
			'title'      => esc_html__( 'Button Hover Color', 'capture' ),
			'std'        => '#969696',
			'dependency' => $readmore,
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'         => 'readmore_border_hover_color_' . $unique_id,
			'type'       => 'color',
			'title'      => esc_html__( 'Button Border Hover Color', 'capture' ),
			'std'        => '#969696',
			'dependency' => $readmore,
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'         => 'readmore_btn_padding_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Button Padding', 'capture' ),
			'sub_desc'   => esc_html__( 'Set Posts button padding from here.', 'capture' ),
			'std'        => [
				'top'    => '20px',
				'right'  => '40px',
				'bottom' => '16px',
				'left'   => '40px',
			],
			'dependency' => $readmore,
		] : null,
		// Post Container.
		( 'layout-2' === $posts_layout ) ? [
			'id'    => 'post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'capture' ),
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'       => 'post_background_' . $unique_id,
			'type'     => 'background',
			'title'    => esc_html__( 'Post Background Color', 'capture' ),
			'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'capture' ),
			'options'  => [
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => [],       // false to disable, array of options to override default ( optional ).
				'attachment'    => [],       // false to disable, array of options to override default ( optional ).
				'position'      => [],       // false to disable, array of options to override default ( optional ).
				'size'          => [],       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => [],       // false to disable, array of options to override default ( optional ).
			],
			'std'      => [
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => [
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				],
				'parallax'      => '0',
			],
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'capture' ),
			'sub_desc' => esc_html__( 'Select border', 'capture' ),
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'       => 'post_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'capture' ),
			'sub_desc' => esc_html__( 'Post margin.', 'capture' ),
			'left'     => false,
			'right'    => false,
			'std'      => [
				'top'    => capture_px2rem( '50px' ),
				'bottom' => '0',
			],
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'       => 'post_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'capture' ),
			'sub_desc' => esc_html__( 'Post padding.', 'capture' ),
			'std'      => [
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			],
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'    => 'post_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Title Font', 'capture' ),
			'std'   => [
				'preview-text'   => 'Post Title Font',
				'preview-color'  => 'light',
				'font-family'    => 'Spartan',
				'font-weight'    => '700',
				'font-size'      => '20px',
				'line-height'    => '1.2',
				'margin-top'     => capture_px2rem( '8px' ),
				'margin-bottom'  => '5px',
				'color'          => '#000000',
				'letter-spacing' => capture_letter_spacing( 20, -16 ),
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .title a',
			],
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'       => 'post_excerpt_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show Post Excerpts', 'capture' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide post excerpt.', 'capture' ),
			'std'      => '1',
		] : null,
		( 'layout-2' === $posts_layout ) ? [
			'id'         => 'post_excerpt_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Post Excerpt Font', 'capture' ),
			'std'        => [
				'preview-text'  => 'Post Excerpt Font',
				'preview-color' => 'light',
				'font-family'   => 'Spartan',
				'font-weight'   => '400',
				'font-size'     => '14px',
				'line-height'   => capture_line_height( 14, 24 ),
				'color'         => '#000000',
				'margin-bottom' => capture_px2rem( 15 ),
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .front-view-content',
			],
			'dependency' => $post_excerpt_dependency,
		] : null,

		/**
		 * Layout HTML Settings
		 *
		 * @package Capture
		 */
		( 'layout-html' === $posts_layout ) ? [
			'id'       => 'post_layout_html_' . $unique_id,
			'type'     => 'ace_editor',
			'mode'     => 'html',
			'title'    => esc_html__( 'HTML Post', 'capture' ),
			'sub_desc' => esc_html__( 'Paste your HTML, Text or other code here.', 'capture' ),
			'std'      => '<img src="' . get_template_directory_uri() . '/images/banner.jpg">',
		] : null,
		( 'layout-html' === $posts_layout ) ? [
			'id'       => 'post_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'capture' ),
			'sub_desc' => esc_html__( 'Post margin.', 'capture' ),
			'left'     => false,
			'right'    => false,
			'std'      => [
				'top'    => capture_px2rem( '50px' ),
				'bottom' => '0',
			],
		] : null,
		( 'layout-html' === $posts_layout ) ? [
			'id'       => 'post_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'capture' ),
			'sub_desc' => esc_html__( 'Post padding.', 'capture' ),
			'std'      => [
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			],
		] : null,

	];
endforeach;
