<?php
/**
 * Header Tab
 *
 * @package Capture
 */

$menus['header'] = [
	'icon'  => 'fa-header',
	'title' => esc_html__( 'Header', 'capture' ),
];

$menus['header']['child']['header-general'] = [
	'title' => esc_html__( 'General', 'capture' ),
	'desc'  => esc_html__( 'From here, you can control the elements of header section.', 'capture' ),
];

// Dependency for header layout 2.
$header_layout2_dependency = [
	'relation' => 'and',
	[
		'field'      => 'header_styles',
		'value'      => 'header-layout2',
		'comparison' => '==',
	],
];
// Responsive Floating.
$sticky_nav = [
	'relation' => 'and',
	[
		'field'      => 'sticky_nav',
		'value'      => '1',
		'comparison' => '==',
	],
];

$sections['header-general'] = [

	[
		'id'       => 'header_styles',
		'type'     => 'radio_img',
		'title'    => esc_html__( 'Header Styling', 'capture' ),
		'sub_desc' => wp_kses( __( 'Choose the <strong>Header design</strong> for your site.', 'capture' ), [ 'strong' => '' ] ),
		'options'  => [
			'header-default' => [ 'img' => $uri . 'headers/header-default.jpg' ],
			'header-layout2' => [ 'img' => $uri . 'headers/header-layout2.jpg' ],
		],
		'std'      => 'header-default',
	],

	[
		'id'    => 'header_general_heading',
		'type'  => 'heading',
		'title' => esc_html__( 'Header General Settings', 'capture' ),
	],

	[
		'id'       => 'sticky_nav',
		'type'     => 'switch',
		'title'    => esc_html__( 'Floating Navigation Menu', 'capture' ),
		// translators: Floating Navigation Menu with strong tag.
		'sub_desc' => sprintf( esc_html__( 'Use this button to enable %s.', 'capture' ), '<strong>' . esc_html__( 'Floating Navigation Menu', 'capture' ) . '</strong>' ),
		'std'      => '0',
	],

	[
		'id'         => 'sticky_responsive_nav',
		'type'       => 'switch',
		'title'      => esc_html__( 'Floating Navigation Responsive', 'capture' ),
		'sub_desc'   => wp_kses( __( 'Use this button to Show or Hide the <strong>Floating Navigation Menu</strong> on Responsive screen.', 'capture' ), [ 'strong' => '' ] ),
		'std'        => '0',
		'dependency' => $sticky_nav,
	],

	[
		'id'       => 'hide_logo',
		'type'     => 'switch',
		'title'    => esc_html__( 'Show Logo', 'capture' ),
		'sub_desc' => wp_kses( __( 'Use this button to Show or Hide the <strong>Logo</strong> completely.', 'capture' ), [ 'strong' => '' ] ),
		'std'      => '1',
	],
	[
		'id'       => 'mts_header_social_share',
		'type'     => 'switch',
		'title'    => esc_html__( 'Show Header Social Icons', 'capture' ),
		'sub_desc' => wp_kses( __( 'Use this button to Show or Hide the <strong>Header social icons</strong> completely.', 'capture' ), [ 'strong' => '' ] ),
		'std'      => '0',
	],

	[
		'id'         => 'header_social_icons',
		'title'      => esc_html__( 'Header Social Icons', 'capture' ),
		'sub_desc'   => esc_html__( 'Add Social Media icons in header.', 'capture' ),
		'type'       => 'group',
		'groupname'  => esc_html__( 'Header Icon', 'capture' ), // Group name.
		'subfields'  => [
			[
				'id'    => 'header_icon_title',
				'type'  => 'text',
				'title' => esc_html__( 'Title', 'capture' ),
			],
			[
				'id'    => 'header_icon',
				'type'  => 'icon_select',
				'title' => esc_html__( 'Icon', 'capture' ),
			],
			[
				'id'    => 'header_icon_link',
				'type'  => 'text',
				'title' => esc_html__( 'URL', 'capture' ),
			],
			[
				'id'    => 'header_icon_bgcolor',
				'type'  => 'color',
				'title' => esc_html__( 'Header icon background color', 'capture' ),
			],
			[
				'id'    => 'header_icon_hover_bgcolor',
				'type'  => 'color',
				'title' => esc_html__( 'Header icon background hover color', 'capture' ),
			],
			[
				'id'    => 'header_icon_color',
				'type'  => 'color',
				'title' => esc_html__( 'Header icon color', 'capture' ),
			],
			[
				'id'    => 'header_icon_hover_color',
				'type'  => 'color',
				'title' => esc_html__( 'Header icon hover color', 'capture' ),
			],
			[
				'id'    => 'header_icon_margin',
				'type'  => 'margin',
				'title' => esc_html__( 'Header icon Margin', 'capture' ),
			],
			[
				'id'    => 'header_icon_padding',
				'type'  => 'margin',
				'title' => esc_html__( 'Header icon Padding', 'capture' ),
			],
			[
				'id'    => 'header_icon_border_radius',
				'type'  => 'text',
				'class' => 'small-text',
				'title' => esc_html__( 'Header icon border radius', 'capture' ),
				'args'  => [ 'type' => 'number' ],
			],
		],
		'std'        => [
			'facebook'  => [
				'group_title'               => 'Facebook',
				'group_sort'                => '1',
				'header_icon_title'         => 'Facebook',
				'header_icon'               => 'facebook-official',
				'header_icon_link'          => '#',
				'header_icon_bgcolor'       => '',
				'header_icon_hover_bgcolor' => '',
				'header_icon_color'         => '#000000',
				'header_icon_hover_color'   => '#969696',
				'header_icon_margin'        => [
					'top'    => '0',
					'right'  => capture_px2rem( '30px' ),
					'bottom' => '0',
					'left'   => '0',
				],
				'header_icon_padding'       => [
					'top'    => '0',
					'right'  => '0',
					'bottom' => '0',
					'left'   => '0',
				],
				'header_icon_border_radius' => '0',
			],
			'twitter'   => [
				'group_title'               => 'Twitter',
				'group_sort'                => '2',
				'header_icon_title'         => 'Twitter',
				'header_icon'               => 'twitter',
				'header_icon_link'          => '#',
				'header_icon_bgcolor'       => '',
				'header_icon_hover_bgcolor' => '',
				'header_icon_color'         => '#000000',
				'header_icon_hover_color'   => '#969696',
				'header_icon_margin'        => [
					'top'    => '0',
					'right'  => capture_px2rem( '30px' ),
					'bottom' => '0',
					'left'   => '0',
				],
				'header_icon_padding'       => [
					'top'    => '0',
					'right'  => '0',
					'bottom' => '0',
					'left'   => '0',
				],
				'header_icon_border_radius' => '0',
			],
			'instagram' => [
				'group_title'               => 'Instagram',
				'group_sort'                => '3',
				'header_icon_title'         => 'Instagram',
				'header_icon'               => 'instagram',
				'header_icon_link'          => '#',
				'header_icon_bgcolor'       => '',
				'header_icon_hover_bgcolor' => '',
				'header_icon_color'         => '#000000',
				'header_icon_hover_color'   => '#969696',
				'header_icon_margin'        => [
					'top'    => '0',
					'right'  => capture_px2rem( '30px' ),
					'bottom' => '0',
					'left'   => '0',
				],
				'header_icon_padding'       => [
					'top'    => '0',
					'right'  => '0',
					'bottom' => '0',
					'left'   => '0',
				],
				'header_icon_border_radius' => '0',
			],
			'pinterest' => [
				'group_title'               => 'Pinterest',
				'group_sort'                => '4',
				'header_icon_title'         => 'Instagram',
				'header_icon'               => 'pinterest',
				'header_icon_link'          => '#',
				'header_icon_bgcolor'       => '',
				'header_icon_hover_bgcolor' => '',
				'header_icon_color'         => '#000000',
				'header_icon_hover_color'   => '#969696',
				'header_icon_margin'        => [
					'top'    => '0',
					'right'  => capture_px2rem( '30px' ),
					'bottom' => '0',
					'left'   => '0',
				],
				'header_icon_padding'       => [
					'top'    => '0',
					'right'  => '0',
					'bottom' => '0',
					'left'   => '0',
				],
				'header_icon_border_radius' => '0',
			],
		],
		'dependency' => [
			'relation' => 'and',
			[
				'field'      => 'mts_header_social_share',
				'value'      => '1',
				'comparison' => '==',
			],
		],
	],

	[
		'id'    => 'header_container_heading',
		'type'  => 'heading',
		'title' => esc_html__( 'Header Container', 'capture' ),
	],
	[
		'id'       => 'header_margin',
		'type'     => 'margin',
		'title'    => esc_html__( 'Header Margin', 'capture' ),
		'sub_desc' => esc_html__( 'Set header margin from here.', 'capture' ),
		'left'     => false,
		'right'    => false,
		'std'      => [
			'top'    => '0',
			'bottom' => '0',
		],
	],
	[
		'id'       => 'header_padding',
		'type'     => 'margin',
		'title'    => esc_html__( 'Header Padding', 'capture' ),
		'sub_desc' => esc_html__( 'Set header padding from here.', 'capture' ),
		'left'     => false,
		'right'    => false,
		'std'      => [
			'top'    => capture_px2rem( '44px' ),
			'bottom' => capture_px2rem( '36px' ),
		],
	],
	[
		'id'       => 'header_border',
		'type'     => 'border',
		'title'    => esc_html__( 'Border', 'capture' ),
		'sub_desc' => esc_html__( 'Select border.', 'capture' ),
		'std'      => [
			'direction' => 'top',
			'size'      => '1',
			'style'     => 'solid',
			'color'     => '#e1e1e1',
		],
	],
	[
		'id'       => 'header_background',
		'type'     => 'background',
		'title'    => esc_html__( 'Header Background', 'capture' ),
		'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'capture' ),
		'options'  => [
			'color'         => '',            // false to disable, not needed otherwise.
			'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
			'image_upload'  => '',            // false to disable, not needed otherwise.
			'repeat'        => [],       // false to disable, array of options to override default ( optional ).
			'attachment'    => [],       // false to disable, array of options to override default ( optional ).
			'position'      => [],       // false to disable, array of options to override default ( optional ).
			'size'          => [],       // false to disable, array of options to override default ( optional ).
			'gradient'      => '',            // false to disable, not needed otherwise.
			'parallax'      => [],       // false to disable, array of options to override default ( optional ).
		],
		'std'      => [
			'color'         => '#ffffff',
			'use'           => 'pattern',
			'image_pattern' => 'nobg',
			'image_upload'  => '',
			'repeat'        => 'repeat',
			'attachment'    => 'scroll',
			'position'      => 'left top',
			'size'          => 'cover',
			'gradient'      => [
				'from'      => '#ffffff',
				'to'        => '#000000',
				'direction' => '0deg',
			],
			'parallax'      => '0',
		],
	],
];
