<?php
/**
 * Single Photos CPT Tab
 *
 * @package Capture
 */

$menus['homepage-single'] = [
	'icon'  => 'fa-picture-o',
	'title' => esc_html__( 'Single Photos', 'capture' ),
	'desc'  => esc_html__( 'From here, you can control the elements of the Single Photos.', 'capture' ),
];

// Dependency check - Featured Image Size.
$header_photos_image_size = [
	'relation' => 'and',
	[
		'field'      => 'header_photos_image_size',
		'value'      => 'full',
		'comparison' => '==',
	],
];

$sections['homepage-single'] = [
	[
		'id'       => 'header_photos_image_size',
		'type'     => 'button_set',
		'title'    => esc_html__( 'Header Size', 'capture' ),
		'sub_desc' => esc_html__( 'Choose the Header image size', 'capture' ),
		'options'  => [
			'default' => esc_html__( 'Content Size', 'capture' ),
			'full'    => esc_html__( 'Full Width', 'capture' ),
		],
		'std'      => 'full',
	],
	[
		'id'         => 'header_photos_prev_next',
		'type'       => 'switch',
		'title'      => esc_html__( 'Show Next/ Previous Article', 'capture' ),
		'sub_desc'   => esc_html__( 'Use this button to show or hide preview and next article buttons.', 'capture' ),
		'std'        => '1',
		'dependency' => $header_photos_image_size,
	],
	[
		'id'       => 'mts_single_photos_layout',
		'type'     => 'layout2',
		'title'    => esc_html__( 'Single Photos Layout', 'capture' ),
		'sub_desc' => esc_html__( 'Customize the look of single photos.', 'capture' ),
		'options'  => [
			'enabled'  => [
				'content' => [
					'label'     => esc_html__( 'Post Content', 'capture' ),
					'subfields' => [],
				],
				'tags'    => [
					'label'     => esc_html__( 'Tags & Social', 'capture' ),
					'subfields' => [],
				],
				'author'  => [
					'label'     => esc_html__( 'Author Box', 'capture' ),
					'subfields' => [],
				],
			],
			'disabled' => [
				'related' => [
					'label'     => esc_html__( 'Related Posts', 'capture' ),
					'subfields' => [],
				],
				'subscribe' => [
					'label'     => esc_html__( 'Subscribe Box', 'capture' ),
					'subfields' => [],
				],
			],
		],
	],
	[
		'id'       => 'mts_photos_headline_meta_info',
		'type'     => 'layout2',
		'title'    => esc_html__( 'Single Photos Meta Info', 'capture' ),
		'sub_desc' => esc_html__( 'Organize how you want the post meta info to appear on single photos meta info.', 'capture' ),
		'options'  => [
			'enabled'  => [
				'category' => [
					'label'     => esc_html__( 'Categories', 'capture' ),
					'subfields' => [
						[
							'id'    => 'mts_single_meta_info_category_icon',
							'type'  => 'icon_select',
							'title' => esc_html__( 'Select Icon', 'capture' ),
						],
					],
				],
				'date'     => [
					'label'     => esc_html__( 'Date', 'capture' ),
					'subfields' => [
						[
							'id'    => 'mts_single_meta_info_date_icon',
							'type'  => 'icon_select',
							'title' => esc_html__( 'Select Icon', 'capture' ),
						],
					],
				],
			],
			'disabled' => [
				'author'  => [
					'label'     => esc_html__( 'Author Name', 'capture' ),
					'subfields' => [
						[
							'id'    => 'mts_single_meta_info_author_icon',
							'type'  => 'icon_select',
							'title' => esc_html__( 'Select Icon', 'capture' ),
						],
					],
				],
				'comment' => [
					'label'     => esc_html__( 'Comment Count', 'capture' ),
					'subfields' => [
						[
							'id'    => 'mts_single_meta_info_comment_icon',
							'type'  => 'icon_select',
							'title' => esc_html__( 'Select Icon', 'capture' ),
						],
					],
				],
			],
		],
	],
	[
		'id'    => 'photo_typography_heading',
		'type'  => 'heading',
		'title' => esc_html__( 'Typography', 'capture' ),
	],
	[
		'id'    => 'single_photo_title_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Single Photo Title', 'capture' ),
		'std'   => [
			'preview-text'   => 'Single Photo Title',
			'preview-color'  => 'light',
			'font-family'    => 'Spartan',
			'font-weight'    => '700',
			'font-size'      => capture_px2rem( '32px' ),
			'line-height'    => capture_line_height( 32, 40 ),
			'margin-bottom'  => '0',
			'color'          => '#000000',
			'letter-spacing' => capture_letter_spacing( 32, -16 ),
			'css-selectors'  => '.single-cpt-photo .single-title',
		],
	],
	[
		'id'    => 'single_photo_nextprev_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Next/ Prev Font', 'capture' ),
		'std'   => [
			'preview-text'   => 'Next/ Prev Font',
			'preview-color'  => 'light',
			'font-family'    => 'Spartan',
			'font-weight'    => '600',
			'font-size'      => '12px',
			'color'          => '#969696',
			'letter-spacing' => capture_letter_spacing( 12, 167 ),
			'additional-css' => 'text-transform: uppercase;',
			'css-selectors'  => '.single-full-header .prev-next a',
		],
	],
	[
		'id'    => 'single_photo_meta_info_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Single Photo Meta Info Font', 'capture' ),
		'std'   => [
			'preview-text'   => 'Post Meta Info Font',
			'preview-color'  => 'light',
			'font-family'    => 'Spartan',
			'font-weight'    => '700',
			'font-size'      => '12px',
			'color'          => '#000000',
			'margin-bottom'  => '2px',
			'letter-spacing' => capture_letter_spacing( 12, 167 ),
			'additional-css' => 'text-transform: uppercase;',
			'css-selectors'  => '.single_post .post-info, .single-full-header.single-cpt-photo .post-info',
		],
	],
	[
		'id'    => 'model_title_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Model Title', 'capture' ),
		'std'   => [
			'preview-text'   => 'Model Title',
			'preview-color'  => 'light',
			'font-family'    => 'Spartan',
			'font-weight'    => '700',
			'font-size'      => '12px',
			'color'          => '#969696',
			'letter-spacing' => capture_letter_spacing( 12, 167 ),
			'additional-css' => 'text-transform: uppercase;',
			'css-selectors'  => '.single-photos .model-title',
		],
	],
	[
		'id'    => 'model_desc_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Model Description', 'capture' ),
		'std'   => [
			'preview-text'   => 'Model Description',
			'preview-color'  => 'light',
			'font-family'    => 'Spartan',
			'font-weight'    => '700',
			'font-size'      => '12px',
			'color'          => '#000000',
			'letter-spacing' => capture_letter_spacing( 12, 167 ),
			'additional-css' => 'text-transform: uppercase;',
			'css-selectors'  => '.single-photos .model-description',
		],
	],
];
