<?php
/**
 * HomePage Photos CPT Tab
 *
 * @package Capture
 */

$menus['homepage'] = [
	'icon'  => 'fa-home',
	'title' => esc_html__( 'Homepage', 'capture' ),
	'desc'  => esc_html__( 'From here, you can control the elements of the Photos Custom Post.', 'capture' ),
];

// Dependency check that Like button is enable.
$photo_like_button = [
	'relation' => 'and',
	[
		'field'      => 'photo_like_button',
		'value'      => '1',
		'comparison' => '==',
	],
];
// Dependency check that Like button is enable.
$photo_readmore_button = [
	'relation' => 'and',
	[
		'field'      => 'photo_readmore_button',
		'value'      => '1',
		'comparison' => '==',
	],
];

$photos_hover_dependency = [
	'relation' => 'and',
	[
		'field'      => 'photos_hover',
		'value'      => '1',
		'comparison' => '==',
	],
];

$sections['homepage'] = [
	[
		'id'       => 'photo_pagenavigation_type',
		'type'     => 'radio',
		'title'    => esc_html__( 'Pagination Type', 'capture' ),
		'sub_desc' => esc_html__( 'Select pagination type.', 'capture' ),
		'options'  => [
			'0' => esc_html__( 'Default (Next / Previous)', 'capture' ),
			'1' => esc_html__( 'Numbered (1 2 3 4...)', 'capture' ),
			'2' => esc_html__( 'AJAX (Load More Button)', 'capture' ),
			'3' => esc_html__( 'AJAX (Auto Infinite Scroll)', 'capture' ),
		],
		'std'      => '1',
	],
	[
		'id'       => 'photo_post_num',
		'type'     => 'text',
		'class'    => 'small-text',
		'title'    => esc_html__( 'Number of Posts', 'capture' ),
		'sub_desc' => esc_html__( 'Enter number of posts to show on photos archive. Set -1 to show all posts.', 'capture' ),
		'args'     => [ 'type' => 'number' ],
		'std'      => '6',
	],
	[
		'id'       => 'photo_readmore_button',
		'type'     => 'switch',
		'title'    => esc_html__( 'Read More Button', 'capture' ),
		'sub_desc' => esc_html__( 'Enable or disable Read More button with this option.', 'capture' ),
		'std'      => '1',
	],
	[
		'id'         => 'photo_readmore_title',
		'type'       => 'text',
		'title'      => esc_html__( 'Read More Title', 'capture' ),
		'sub_desc'   => esc_html__( 'Enter Read More title text it will be shown in lightbox popup.', 'capture' ),
		'std'        => 'View Details',
		'dependency' => $photo_readmore_button,
	],
	[
		'id'       => 'photo_like_button',
		'type'     => 'switch',
		'title'    => esc_html__( 'Like Button', 'capture' ),
		'sub_desc' => esc_html__( 'Enable or disable Like button with this option.', 'capture' ),
		'std'      => '1',
	],
	[
		'id'       => 'photos_hover',
		'type'     => 'switch',
		'title'    => esc_html__( 'Post Hover Effect', 'capture' ),
		'sub_desc' => esc_html__( 'Use this button to show or hide hover effect.', 'capture' ),
		'std'      => '1',
	],
	[
		'id'         => 'photos_overlay',
		'type'       => 'color',
		'title'      => esc_html__( 'Post Overlay Background', 'capture' ),
		'args'       => [ 'opacity' => true ],
		'std'        => 'rgba(255,255,255,0.75)',
		'dependency' => $photos_hover_dependency,
	],
	[
		'id'    => 'photo_typo',
		'type'  => 'heading',
		'title' => esc_html__( 'Typography Settings', 'capture' ),
	],
	[
		'id'    => 'photo_title_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Title Font', 'capture' ),
		'std'   => [
			'preview-text'   => 'Title Font',
			'preview-color'  => 'dark',
			'font-family'    => 'Spartan',
			'font-weight'    => '600',
			'font-size'      => '12px',
			'color'          => '#ffffff',
			'letter-spacing' => capture_letter_spacing( 12, 167 ),
			'margin-bottom'  => '8px',
			'additional-css' => 'text-transform: uppercase;',
			'css-selectors'  => '.capture-cpt-photos .mfp-title',
		],
	],
	[
		'id'    => 'photo_popup_counter_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Counter Font', 'capture' ),
		'std'   => [
			'preview-text'   => 'Counter Font',
			'preview-color'  => 'dark',
			'font-family'    => 'Spartan',
			'font-weight'    => '600',
			'font-size'      => '12px',
			'color'          => '#c6c6c6',
			'letter-spacing' => capture_letter_spacing( 12, 167 ),
			'additional-css' => 'text-transform: uppercase;',
			'css-selectors'  => '.capture-cpt-photos .mfp-counter',
		],
	],
	[
		'id'         => 'photo_readmore_font',
		'type'       => 'typography',
		'title'      => esc_html__( 'Read More Font', 'capture' ),
		'std'        => [
			'preview-text'   => 'Read More Font',
			'preview-color'  => 'dark',
			'font-family'    => 'Spartan',
			'font-weight'    => '600',
			'font-size'      => '12px',
			'color'          => '#808080',
			'letter-spacing' => capture_letter_spacing( 12, 167 ),
			'additional-css' => 'text-transform: uppercase;',
			'css-selectors'  => '.capture-cpt-photos .photo-readmore a',
		],
		'dependency' => $photo_readmore_button,
	],
	[
		'id'         => 'photo_like_font',
		'type'       => 'typography',
		'title'      => esc_html__( 'Post Like Font', 'capture' ),
		'std'        => [
			'preview-text'   => 'Post Like Font',
			'preview-color'  => 'dark',
			'font-family'    => 'Spartan',
			'font-weight'    => '600',
			'font-size'      => '12px',
			'color'          => '#ffffff',
			'letter-spacing' => capture_letter_spacing( 12, 167 ),
			'css-selectors'  => '.capture-cpt-photos .photo-like a',
		],
		'dependency' => $photo_like_button,
	],
	[
		'id'         => 'photo_like_hover_font',
		'type'       => 'typography',
		'title'      => esc_html__( 'Post Like Hover Font', 'capture' ),
		'std'        => [
			'preview-text'   => 'Post Like Hover Font',
			'preview-color'  => 'light',
			'font-family'    => 'Spartan',
			'font-weight'    => '600',
			'font-size'      => '12px',
			'color'          => '#000000',
			'letter-spacing' => capture_letter_spacing( 12, 167 ),
			'css-selectors'  => '.photo-like-button a',
		],
		'dependency' => $photo_like_button,
	],
];
