<?php
/**
 * Single AuthorBox
 *
 * @package Capture
 */

$menus['single-authorbox'] = [
	'icon'  => 'fa-pencil',
	'title' => esc_html__( 'Author Box', 'capture' ),
	'desc'  => esc_html__( 'From here, you can control the appearance and functionality of Author box in single posts page.', 'capture' ),
];

$authorbox_social_share = [
	'relation' => 'and',
	[
		'field'      => 'authorbox_social_share',
		'value'      => '1',
		'comparison' => '==',
	],
];

$sections['single-authorbox'] = [

	[
		'id'    => 'authorbox_heading',
		'type'  => 'heading',
		'title' => esc_html__( 'Author box Settings', 'capture' ),
	],
	[
		'id'       => 'authorbox_background',
		'type'     => 'background',
		'title'    => esc_html__( 'Author box Background', 'capture' ),
		'sub_desc' => esc_html__( 'Set background color, pattern and image for subscribe box from here.', 'capture' ),
		'options'  => [
			'color'         => '',            // false to disable, not needed otherwise.
			'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
			'image_upload'  => '',            // false to disable, not needed otherwise.
			'repeat'        => [],       // false to disable, array of options to override default ( optional ).
			'attachment'    => [],       // false to disable, array of options to override default ( optional ).
			'position'      => [],       // false to disable, array of options to override default ( optional ).
			'size'          => [],       // false to disable, array of options to override default ( optional ).
			'gradient'      => '',            // false to disable, not needed otherwise.
			'parallax'      => [],       // false to disable, array of options to override default ( optional ).
		],
		'std'      => [
			'color'         => '',
			'use'           => 'pattern',
			'image_pattern' => 'nobg',
			'image_upload'  => '',
			'repeat'        => 'repeat',
			'attachment'    => 'scroll',
			'position'      => 'left top',
			'size'          => 'cover',
			'gradient'      => [
				'from'      => '#ffffff',
				'to'        => '#000000',
				'direction' => '0deg',
			],
			'parallax'      => '0',
		],
	],
	[
		'id'       => 'author_box_title',
		'type'     => 'text',
		'title'    => esc_html__( 'Author Box Title', 'capture' ),
		'sub_desc' => esc_html__( 'Enter author box title.', 'capture' ),
		'std'      => 'About the Photographer',
	],
	[
		'id'       => 'authorbox_margin',
		'type'     => 'margin',
		'title'    => esc_html__( 'Margin', 'capture' ),
		'sub_desc' => esc_html__( 'Set Author box margin from here.', 'capture' ),
		'std'      => [
			'top'    => '0',
			'right'  => '0',
			'bottom' => capture_px2rem( '65px' ),
			'left'   => '0',
		],
	],
	[
		'id'       => 'authorbox_padding',
		'type'     => 'margin',
		'title'    => esc_html__( 'Padding', 'capture' ),
		'sub_desc' => esc_html__( 'Set Author box padding from here.', 'capture' ),
		'std'      => [
			'top'    => '',
			'right'  => '',
			'bottom' => capture_px2rem( '40px' ),
			'left'   => '',
		],
	],
	[
		'id'       => 'authorbox_border',
		'type'     => 'border',
		'title'    => esc_html__( 'Border', 'capture' ),
		'sub_desc' => esc_html__( 'Select border', 'capture' ),
		'std'      => [
			'direction' => 'bottom',
			'size'      => '1',
			'style'     => 'solid',
			'color'     => '#e1e1e1',
		],
	],
	[
		'id'       => 'authorbox_border_radius',
		'type'     => 'text',
		'class'    => 'small-text',
		'title'    => esc_html__( 'Border Radius', 'capture' ),
		'sub_desc' => esc_html__( 'Author box border radius.', 'capture' ),
		'std'      => '0',
		'args'     => [ 'type' => 'number' ],
	],
	[
		'id'    => 'authorbox_title_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Author Box Title Font', 'capture' ),
		'std'   => [
			'preview-text'   => 'Author Box Title Font',
			'preview-color'  => 'light',
			'font-family'    => 'Spartan',
			'font-weight'    => '600',
			'font-size'      => '12px',
			'color'          => '#969696',
			'letter-spacing' => capture_letter_spacing( 12, 167 ),
			'additional-css' => 'text-transform: uppercase;',
			'margin-bottom'  => capture_px2rem( '28px' ),
			'css-selectors'  => '.postauthor h4',
		],
	],
	[
		'id'    => 'authorbox_author_name_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Author Box Name Font', 'capture' ),
		'std'   => [
			'preview-text'   => 'Author Box Name Font',
			'preview-color'  => 'light',
			'font-family'    => 'Spartan',
			'font-weight'    => '700',
			'font-size'      => capture_px2rem( '32px' ),
			'line-height'    => '1.2',
			'color'          => '#000000',
			'margin-bottom'  => capture_px2rem( '16px' ),
			'letter-spacing' => capture_letter_spacing( 32, -16 ),
			'additional-css' => 'text-transform: capitalize;',
			'css-selectors'  => '.postauthor h5, .postauthor h5 a',
		],
	],
	[
		'id'    => 'authorbox_text_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Author Box Text Font', 'capture' ),
		'std'   => [
			'preview-text'  => 'Author Box Text Font',
			'preview-color' => 'light',
			'font-family'   => 'Spartan',
			'font-weight'   => '400',
			'font-size'     => '14px',
			'line-height'   => capture_line_height( 14, 24 ),
			'color'         => '#000000',
			'margin-top'    => capture_px2rem( '5px' ),
			'margin-bottom' => '8px',
			'css-selectors' => '.postauthor p',
		],
	],
	[
		'id'    => 'author_img_heading',
		'type'  => 'heading',
		'title' => esc_html__( 'Author Image Settings', 'capture' ),
	],
	[
		'id'       => 'author_box_image',
		'type'     => 'switch',
		'title'    => esc_html__( 'Show Author Image', 'capture' ),
		'sub_desc' => esc_html__( 'Use this button to show/hide author image.', 'capture' ),
		'std'      => '1',
	],
	[
		'id'       => 'single_author_image_margin',
		'type'     => 'margin',
		'title'    => esc_html__( 'Margin', 'capture' ),
		'sub_desc' => esc_html__( 'Set Author image margin from here.', 'capture' ),
		'std'      => [
			'top'    => '',
			'right'  => capture_px2rem( '64px' ),
			'bottom' => '0',
			'left'   => '0',
		],
	],
	[
		'id'       => 'single_author_image_border_radius',
		'type'     => 'text',
		'class'    => 'small-text',
		'title'    => esc_html__( 'Border Radius', 'capture' ),
		'sub_desc' => esc_html__( 'Author image border radius.', 'capture' ),
		'std'      => '128',
		'args'     => [ 'type' => 'number' ],
	],
	[
		'id'    => 'single_authorbox_social_heading',
		'type'  => 'heading',
		'title' => esc_html__( 'Author box Social Settings', 'capture' ),
	],
	[
		'id'       => 'authorbox_social_share',
		'type'     => 'switch',
		'title'    => esc_html__( 'Show Author Social Share', 'capture' ),
		'sub_desc' => esc_html__( 'Enable/Disable author social share in the authorbox.', 'capture' ),
		'std'      => '0',
	],
	[
		'id'         => 'author_social_margin',
		'type'       => 'margin',
		'title'      => esc_html__( 'Margin', 'capture' ),
		'sub_desc'   => esc_html__( 'Set author social share margin from here.', 'capture' ),
		'std'        => [
			'top'    => '0',
			'right'  => capture_px2rem( '16px' ),
			'bottom' => '10px',
			'left'   => '0',
		],
		'dependency' => $authorbox_social_share,
	],
	[
		'id'         => 'author_social_padding',
		'type'       => 'margin',
		'title'      => esc_html__( 'Padding', 'capture' ),
		'sub_desc'   => esc_html__( 'Set author social share padding from here.', 'capture' ),
		'std'        => [
			'top'    => '0',
			'right'  => '0',
			'bottom' => '0',
			'left'   => '0',
		],
		'dependency' => $authorbox_social_share,
	],
	[
		'id'         => 'author_social_background',
		'type'       => 'color',
		'title'      => esc_html__( 'Social Background Color', 'capture' ),
		'sub_desc'   => esc_html__( 'The theme comes with unlimited color schemes for your theme\'s styling.', 'capture' ),
		'dependency' => $authorbox_social_share,
	],
	[
		'id'         => 'author_social_hover_background',
		'type'       => 'color',
		'title'      => esc_html__( 'Social Background Hover Color', 'capture' ),
		'sub_desc'   => esc_html__( 'The theme comes with unlimited color schemes for your theme\'s styling.', 'capture' ),
		'dependency' => $authorbox_social_share,
	],
	[
		'id'         => 'author_social_color',
		'type'       => 'color',
		'title'      => esc_html__( 'Social Color', 'capture' ),
		'sub_desc'   => esc_html__( 'The theme comes with unlimited color schemes for your theme\'s styling.', 'capture' ),
		'std'        => '#000000',
		'dependency' => $authorbox_social_share,
	],
	[
		'id'         => 'author_social_hover_color',
		'type'       => 'color',
		'title'      => esc_html__( 'Social Hover Color', 'capture' ),
		'sub_desc'   => esc_html__( 'The theme comes with unlimited color schemes for your theme\'s styling.', 'capture' ),
		'std'        => capture_get_settings( 'secondary_color_scheme' ),
		'dependency' => $authorbox_social_share,
	],
	[
		'id'         => 'author_social_border_radius',
		'type'       => 'text',
		'class'      => 'small-text',
		'title'      => esc_html__( 'Social border radius', 'capture' ),
		'std'        => '0',
		'args'       => [ 'type' => 'number' ],
		'dependency' => $authorbox_social_share,
	],
];
