<?php
/**
 * Single Related Posts
 *
 * @package Capture
 */

$menus['single-related'] = [
	'icon'  => 'fa-sitemap',
	'title' => esc_html__( 'Related Posts', 'capture' ),
	'desc'  => esc_html__( 'From here, you can control the appearance and functionality of related posts in single posts page.', 'capture' ),
];

$default_related_post = [
	'relation' => 'and',
	[
		'field'      => 'related_posts_layouts',
		'value'      => 'default',
		'comparison' => '==',
	],
];

$related_post_excerpt = [
	'relation' => 'and',
	[
		'field'      => 'related_post_excerpt',
		'value'      => '1',
		'comparison' => '==',
	],
];

$related_readmore = [
	'relation' => 'and',
	[
		'field'      => 'related_readmore',
		'value'      => '1',
		'comparison' => '==',
	],
];

$sections['single-related'] = [

	[
		'id'       => 'related_post_title',
		'type'     => 'text',
		'title'    => esc_html__( 'Related Posts Title', 'capture' ),
		'sub_desc' => esc_html__( 'Enter the title text to show in the related posts section.', 'capture' ),
		'std'      => 'Related Posts',
	],
	[
		'id'       => 'related_posts_position',
		'type'     => 'button_set',
		'title'    => esc_html__( 'Related Posts Position', 'capture' ),
		'sub_desc' => esc_html__( 'Choose the position for related posts, below content will be Full width', 'capture' ),
		'options'  => [
			'default' => esc_html__( 'Default', 'capture' ),
			'full'    => esc_html__( 'Below Content', 'capture' ),
		],
		'std'      => 'full',
	],
	[
		'id'       => 'related_posts_layouts',
		'type'     => 'radio_img',
		'title'    => esc_html__( 'Related Posts Layouts', 'capture' ),
		'sub_desc' => esc_html__( 'Choose the Related Posts layouts for your site.', 'capture' ),
		'options'  => [
			'default'  => [ 'img' => $uri . 'related/r1.jpg' ],
			'related2' => [ 'img' => $uri . 'related/r2.jpg' ],
			'related3' => [ 'img' => $uri . 'related/r3.jpg' ],
			'related5' => [ 'img' => $uri . 'related/r5.jpg' ],
			'related6' => [ 'img' => $uri . 'related/r6.jpg' ],
		],
		'std'      => 'default',
	],
	[
		'id'         => 'related_posts_grid',
		'type'       => 'select',
		'class'      => 'small',
		'title'      => esc_html__( 'Grid', 'capture' ),
		'sub_desc'   => esc_html__( 'Select the number of grid for Related Posts.', 'capture' ),
		'options'    => [
			'grid2' => esc_html__( '2', 'capture' ),
			'grid3' => esc_html__( '3', 'capture' ),
			'grid4' => esc_html__( '4', 'capture' ),
		],
		'std'        => 'grid3',
		'dependency' => $default_related_post,
	],
	[
		'id'       => 'mts_related_postsnum',
		'type'     => 'text',
		'class'    => 'small-text',
		'title'    => esc_html__( 'Number of related posts', 'capture' ),
		'sub_desc' => esc_html__( 'Enter the number of posts to show in the related posts section.', 'capture' ),
		'std'      => '3',
		'args'     => [
			'type' => 'number',
		],
	],
	[
		'id'       => 'related_post_excerpt',
		'type'     => 'switch',
		'title'    => esc_html__( 'Show Post Excerpts', 'capture' ),
		'sub_desc' => esc_html__( 'Use this button to show or hide post excerpt.', 'capture' ),
		'std'      => '1',
	],
	[
		'id'         => 'related_excerpt',
		'type'       => 'text',
		'class'      => 'small-text',
		'title'      => esc_html__( 'Excerpt Length', 'capture' ),
		'sub_desc'   => esc_html__( 'Max lenght is 55 Words.', 'capture' ),
		'args'       => [ 'type' => 'number' ],
		'std'        => '28',
		'dependency' => $related_post_excerpt,
	],
	[
		'id'         => 'related_posts_adcode',
		'type'       => 'ace_editor',
		'mode'       => 'html',
		'title'      => esc_html__( 'Related Posts Ad', 'capture' ),
		'sub_desc'   => esc_html__( 'Paste your Adsense, BSA or other ad code here to show ads in Related Posts Area.', 'capture' ),
		'dependency' => [
			'relation' => 'or',
			[
				'field'      => 'related_posts_layouts',
				'value'      => 'related5',
				'comparison' => '==',
			],
			[
				'field'      => 'related_posts_layouts',
				'value'      => 'related6',
				'comparison' => '==',
			],
		],
	],
	[
		'id'         => 'related_post_alignment',
		'type'       => 'button_set',
		'title'      => esc_html__( 'Post Alignment', 'capture' ),
		'sub_desc'   => esc_html__( 'Choose Related Post alignment', 'capture' ),
		'options'    => [
			'left'   => esc_html__( 'Left', 'capture' ),
			'center' => esc_html__( 'Center', 'capture' ),
			'right'  => esc_html__( 'Right', 'capture' ),
		],
		'std'        => 'center',
		'dependency' => $default_related_post,
	],
	[
		'id'       => 'mts_related_headline_meta_info',
		'type'     => 'layout2',
		'title'    => esc_html__( 'Related Meta Info', 'capture' ),
		'sub_desc' => esc_html__( 'Organize how you want the post meta info to appear on single page', 'capture' ),
		'options'  => [
			'enabled'  => [
				'category' => [
					'label'     => esc_html__( 'Categories', 'capture' ),
					'subfields' => [
						[
							'id'    => 'mts_related_meta_info_category_icon',
							'type'  => 'icon_select',
							'title' => esc_html__( 'Select Icon', 'capture' ),
						],
					],
				],
				'date'     => [
					'label'     => esc_html__( 'Date', 'capture' ),
					'subfields' => [
						[
							'id'    => 'mts_related_meta_info_date_icon',
							'type'  => 'icon_select',
							'title' => esc_html__( 'Select Icon', 'capture' ),
						],
					],
				],
			],
			'disabled' => [
				'author'  => [
					'label'     => esc_html__( 'Author Name', 'capture' ),
					'subfields' => [
						[
							'id'    => 'mts_related_meta_info_author_icon',
							'type'  => 'icon_select',
							'title' => esc_html__( 'Select Icon', 'capture' ),
						],
					],
				],
				'comment' => [
					'label'     => esc_html__( 'Comment Count', 'capture' ),
					'subfields' => [
						[
							'id'    => 'mts_related_meta_info_comment_icon',
							'type'  => 'icon_select',
							'title' => esc_html__( 'Select Icon', 'capture' ),
						],
					],
				],
			],
		],
		'std'      => [
			'enabled'  => [
				'category' => [
					'label'     => esc_html__( 'Categories', 'capture' ),
					'subfields' => [
						[
							'id'    => 'mts_related_meta_info_category_icon',
							'type'  => 'icon_select',
							'title' => esc_html__( 'Select Icon', 'capture' ),
						],
					],
				],
				'date'     => [
					'label'     => esc_html__( 'Date', 'capture' ),
					'subfields' => [
						[
							'id'    => 'mts_related_meta_info_date_icon',
							'type'  => 'icon_select',
							'title' => esc_html__( 'Select Icon', 'capture' ),
						],
					],
				],
			],
			'disabled' => [
				'author'  => [
					'label'     => esc_html__( 'Author Name', 'capture' ),
					'subfields' => [
						[
							'id'    => 'mts_related_meta_info_author_icon',
							'type'  => 'icon_select',
							'title' => esc_html__( 'Select Icon', 'capture' ),
						],
					],
				],
				'comment' => [
					'label'     => esc_html__( 'Comment Count', 'capture' ),
					'subfields' => [
						[
							'id'    => 'mts_related_meta_info_comment_icon',
							'type'  => 'icon_select',
							'title' => esc_html__( 'Select Icon', 'capture' ),
						],
					],
				],
			],
		],
	],
	// Read More Button.
	[
		'id'    => 'related_readmore_heading',
		'type'  => 'heading',
		'title' => esc_html__( 'Read More Button', 'capture' ),
	],
	[
		'id'       => 'related_readmore',
		'type'     => 'switch',
		'title'    => esc_html__( 'Enable/Disable Read More', 'capture' ),
		'sub_desc' => esc_html__( 'Use this button to show or hide Read More.', 'capture' ),
		'std'      => '1',
	],
	[
		'id'         => 'related_readmore_text',
		'type'       => 'text',
		'title'      => esc_html__( 'Button Text', 'capture' ),
		'std'        => 'Read Story',
		'dependency' => $related_readmore,
	],
	[
		'id'         => 'related_readmore_font',
		'type'       => 'typography',
		'title'      => esc_html__( 'Button Font', 'capture' ),
		'std'        => [
			'preview-text'   => 'Read Story Font',
			'preview-color'  => 'light',
			'font-family'    => 'Spartan',
			'font-weight'    => '700',
			'font-size'      => '12px',
			'color'          => '#000000',
			'line-height'    => '1.5',
			'margin-top'     => capture_px2rem( '16px' ),
			'letter-spacing' => capture_letter_spacing( 12, 167 ),
			'additional-css' => 'text-transform: uppercase;',
			'css-selectors'  => '.related-posts .latestPost .readMore a',
		],
		'dependency' => $related_readmore,
	],
	[
		'id'         => 'related_readmore_bg_color',
		'type'       => 'color',
		'title'      => esc_html__( 'Button Background Color', 'capture' ),
		'std'        => '#ffffff',
		'dependency' => $related_readmore,
	],
	[
		'id'         => 'related_readmore_border',
		'type'       => 'border',
		'title'      => esc_html__( 'Button Border', 'capture' ),
		'sub_desc'   => esc_html__( 'Select border.', 'capture' ),
		'std'        => [
			'direction' => 'all',
			'size'      => '1',
			'style'     => 'solid',
			'color'     => '#000000',
		],
		'dependency' => $related_readmore,
	],
	[
		'id'         => 'related_readmore_bg_hover_color',
		'type'       => 'color',
		'title'      => esc_html__( 'Button Background Hover Color', 'capture' ),
		'std'        => '#ffffff',
		'dependency' => $related_readmore,
	],
	[
		'id'         => 'related_readmore_hover_color',
		'type'       => 'color',
		'title'      => esc_html__( 'Button Hover Color', 'capture' ),
		'std'        => '#969696',
		'dependency' => $related_readmore,
	],
	[
		'id'         => 'related_readmore_border_hover_color',
		'type'       => 'color',
		'title'      => esc_html__( 'Button Border Hover Color', 'capture' ),
		'std'        => '#969696',
		'dependency' => $related_readmore,
	],
	[
		'id'       => 'related_readmore_btn_padding',
		'type'     => 'margin',
		'title'    => esc_html__( 'Button Padding', 'capture' ),
		'sub_desc' => esc_html__( 'Set Related Posts button padding from here.', 'capture' ),
		'std'      => [
			'top'    => '20px',
			'right'  => '40px',
			'bottom' => '16px',
			'left'   => '40px',
		],
	],
	[
		'id'    => 'related_posts_container_heading',
		'type'  => 'heading',
		'title' => esc_html__( 'Related Posts Container', 'capture' ),
	],
	[
		'id'       => 'related_posts_background',
		'type'     => 'background',
		'title'    => esc_html__( 'Background', 'capture' ),
		'sub_desc' => esc_html__( 'Set Related Posts background color, pattern and image from here.', 'capture' ),
		'options'  => [
			'color'         => '',            // false to disable, not needed otherwise.
			'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
			'image_upload'  => '',            // false to disable, not needed otherwise.
			'repeat'        => [],       // false to disable, array of options to override default ( optional ).
			'attachment'    => [],       // false to disable, array of options to override default ( optional ).
			'position'      => [],       // false to disable, array of options to override default ( optional ).
			'size'          => [],       // false to disable, array of options to override default ( optional ).
			'gradient'      => '',            // false to disable, not needed otherwise.
			'parallax'      => [],       // false to disable, array of options to override default ( optional ).
		],
		'std'      => [
			'color'         => '',
			'use'           => 'pattern',
			'image_pattern' => 'nobg',
			'image_upload'  => '',
			'repeat'        => 'repeat',
			'attachment'    => 'scroll',
			'position'      => 'left top',
			'size'          => 'cover',
			'gradient'      => [
				'from'      => '#ffffff',
				'to'        => '#000000',
				'direction' => '0deg',
			],
			'parallax'      => '0',
		],
	],
	[
		'id'       => 'related_posts_margin',
		'type'     => 'margin',
		'title'    => esc_html__( 'Margin', 'capture' ),
		'sub_desc' => esc_html__( 'Set Related Posts margin from here.', 'capture' ),
		'std'      => [
			'top'    => capture_px2rem( '68px' ),
			'right'  => '0',
			'bottom' => capture_px2rem( '-28px' ),
			'left'   => '0',
		],
	],
	[
		'id'       => 'related_posts_padding',
		'type'     => 'margin',
		'title'    => esc_html__( 'Padding', 'capture' ),
		'sub_desc' => esc_html__( 'Set Related Posts padding from here.', 'capture' ),
		'std'      => [
			'top'    => '0',
			'right'  => '0',
			'bottom' => '0',
			'left'   => '0',
		],
	],
	[
		'id'       => 'related_posts_border',
		'type'     => 'border',
		'title'    => esc_html__( 'Border', 'capture' ),
		'sub_desc' => esc_html__( 'Select border', 'capture' ),
	],
	[
		'id'    => 'related_posts_typo_heading',
		'type'  => 'heading',
		'title' => esc_html__( 'Typography', 'capture' ),
	],
	[
		'id'    => 'related_posts_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Related Posts Title', 'capture' ),
		'std'   => [
			'preview-text'   => 'Related Posts Title',
			'preview-color'  => 'light',
			'font-family'    => 'Spartan',
			'font-weight'    => '700',
			'font-size'      => '20px',
			'line-height'    => '1.2',
			'margin-top'     => capture_px2rem( '8px' ),
			'margin-bottom'  => '10px',
			'color'          => '#000000',
			'letter-spacing' => capture_letter_spacing( 20, -16 ),
			'css-selectors'  => '.related-posts .latestPost .title a',
		],
	],
	[
		'id'    => 'related_posts_meta_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Related Meta Info Font', 'capture' ),
		'std'   => [
			'preview-text'   => 'Related Post Meta Font',
			'preview-color'  => 'light',
			'font-family'    => 'Spartan',
			'font-weight'    => '700',
			'font-size'      => '12px',
			'color'          => '#969696',
			'margin-top'     => capture_px2rem( '16px' ),
			'letter-spacing' => capture_letter_spacing( 12, 167 ),
			'additional-css' => 'text-transform: uppercase;',
			'css-selectors'  => '.related-posts .latestPost .post-info',
		],
	],
	[
		'id'         => 'related_posts_text_font',
		'type'       => 'typography',
		'title'      => esc_html__( 'Related Posts Text', 'capture' ),
		'std'        => [
			'preview-text'  => 'Related Posts Text',
			'preview-color' => 'light',
			'font-family'   => 'Spartan',
			'font-weight'   => '400',
			'font-size'     => '14px',
			'line-height'   => capture_line_height( 14, 24 ),
			'color'         => '#000000',
			'margin-bottom' => capture_px2rem( '16px' ),
			'css-selectors' => '.related-posts .latestPost .front-view-content',
		],
		'dependency' => $related_post_excerpt,
	],
];
