<?php
/**
 * Single Styling
 *
 * @package Capture
 */

$menus['single-styling'] = [
	'icon'  => 'fa-paint-brush',
	'title' => esc_html__( 'Single Styling', 'capture' ),
	'desc'  => esc_html__( 'From here, you can control the appearance and functionality of your single posts page.', 'capture' ),
];

$sections['single-styling'] = [
	[
		'id'    => 'mts_single_styling_heading',
		'type'  => 'heading',
		'title' => esc_html__( 'Single Styling', 'capture' ),
	],
	[
		'id'       => 'single_background',
		'type'     => 'background',
		'title'    => esc_html__( 'Background', 'capture' ),
		'sub_desc' => esc_html__( 'Set background color, pattern and image of Single, Page, Archive, Search, Category and 404 Page from here.', 'capture' ),
		'options'  => [
			'color'         => '',            // false to disable, not needed otherwise.
			'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
			'image_upload'  => '',            // false to disable, not needed otherwise.
			'repeat'        => [],       // false to disable, array of options to override default ( optional ).
			'attachment'    => [],       // false to disable, array of options to override default ( optional ).
			'position'      => [],       // false to disable, array of options to override default ( optional ).
			'size'          => [],       // false to disable, array of options to override default ( optional ).
			'gradient'      => '',            // false to disable, not needed otherwise.
			'parallax'      => [],       // false to disable, array of options to override default ( optional ).
		],
		'std'      => [
			'color'         => '',
			'use'           => 'pattern',
			'image_pattern' => 'nobg',
			'image_upload'  => '',
			'repeat'        => 'repeat',
			'attachment'    => 'scroll',
			'position'      => 'left top',
			'size'          => 'cover',
			'gradient'      => [
				'from'      => '#ffffff',
				'to'        => '#000000',
				'direction' => '0deg',
			],
			'parallax'      => '0',
		],
	],

	[
		'id'       => 'mts_single_styling_margin',
		'type'     => 'margin',
		'title'    => esc_html__( 'Single Margin', 'capture' ),
		'sub_desc' => esc_html__( 'Set single post margin from here.', 'capture' ),
		'left'     => false,
		'right'    => false,
		'std'      => [
			'top'    => '0',
			'bottom' => capture_px2rem( '32px' ),
		],
	],
	[
		'id'       => 'mts_single_styling_padding',
		'type'     => 'margin',
		'title'    => esc_html__( 'Single Padding', 'capture' ),
		'sub_desc' => esc_html__( 'Set single post padding from here.', 'capture' ),
		'std'      => [
			'top'    => '0',
			'right'  => '0',
			'bottom' => '0',
			'left'   => '0',
		],
	],
	[
		'id'       => 'single_styling_border',
		'type'     => 'border',
		'title'    => esc_html__( 'Border', 'capture' ),
		'sub_desc' => esc_html__( 'Select border', 'capture' ),
	],
	[
		'id'    => 'single_title_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Single Post Title', 'capture' ),
		'std'   => [
			'preview-text'   => 'Single Post Title',
			'preview-color'  => 'light',
			'font-family'    => 'Spartan',
			'font-weight'    => '700',
			'font-size'      => capture_px2rem( '32px' ),
			'line-height'    => capture_line_height( 32, 40 ),
			'margin-top'     => '8px',
			'margin-bottom'  => '0px',
			'color'          => '#000000',
			'letter-spacing' => capture_letter_spacing( 32, -16 ),
			'css-selectors'  => '.single-title',
		],
	],
	[
		'id'    => 'mts_single_meta_info_font',
		'type'  => 'typography',
		'title' => esc_html__( 'Single Meta Info Font', 'capture' ),
		'std'   => [
			'preview-text'   => 'Post Meta Info Font',
			'preview-color'  => 'light',
			'font-family'    => 'Spartan',
			'font-weight'    => '700',
			'font-size'      => '12px',
			'color'          => '#969696',
			'letter-spacing' => capture_letter_spacing( 12, 167 ),
			'additional-css' => 'text-transform: uppercase;',
			'css-selectors'  => '.single-photos .single_post .post-info, .single-full-header .post-info',
		],
	],
	[
		'id'    => 'single_title_heading',
		'type'  => 'heading',
		'title' => esc_html__( 'Single Titles Styling', 'capture' ),
	],
	[
		'id'       => 'single_title_alignment',
		'type'     => 'button_set',
		'title'    => esc_html__( 'Single Page Title Alignment', 'capture' ),
		'sub_desc' => esc_html__( 'Choose the single page title alignment', 'capture' ),
		'options'  => [
			'left'   => esc_html__( 'Left', 'capture' ),
			'center' => esc_html__( 'Center', 'capture' ),
			'right'  => esc_html__( 'Right', 'capture' ),
		],
		'std'      => 'center',
	],
	[
		'id'       => 'single_title_background',
		'type'     => 'background',
		'title'    => esc_html__( 'Single Page Title Background Color', 'capture' ),
		'sub_desc' => esc_html__( 'Set background color, pattern and image from here.', 'capture' ),
		'options'  => [
			'color'         => '',            // false to disable, not needed otherwise.
			'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
			'image_upload'  => '',            // false to disable, not needed otherwise.
			'repeat'        => [],       // false to disable, array of options to override default ( optional ).
			'attachment'    => [],       // false to disable, array of options to override default ( optional ).
			'position'      => [],       // false to disable, array of options to override default ( optional ).
			'size'          => [],       // false to disable, array of options to override default ( optional ).
			'gradient'      => '',            // false to disable, not needed otherwise.
			'parallax'      => [],       // false to disable, array of options to override default ( optional ).
		],
		'std'      => [
			'color'         => '',
			'use'           => 'pattern',
			'image_pattern' => 'nobg',
			'image_upload'  => '',
			'repeat'        => 'repeat',
			'attachment'    => 'scroll',
			'position'      => 'left top',
			'size'          => 'cover',
			'gradient'      => [
				'from'      => '#ffffff',
				'to'        => '#000000',
				'direction' => '0deg',
			],
			'parallax'      => '0',
		],
	],
	[
		'id'       => 'single_title_padding',
		'type'     => 'margin',
		'title'    => esc_html__( 'Single Page Title Padding', 'capture' ),
		'sub_desc' => esc_html__( 'Set single page title padding from here.', 'capture' ),
		'std'      => [
			'top'    => '0',
			'right'  => '0',
			'bottom' => '0',
			'left'   => '0',
		],
	],
	[
		'id'       => 'single_title_border',
		'type'     => 'border',
		'title'    => esc_html__( 'Border', 'capture' ),
		'sub_desc' => esc_html__( 'Select border', 'capture' ),
	],
	[
		'id'       => 'single_page_titles_font',
		'type'     => 'typography',
		'title'    => esc_html__( 'Single Sections Title', 'capture' ),
		'sub_desc' => esc_html__( 'Manage Title typography of Related Posts, Comments and Reply from here.', 'capture' ),
		'std'      => [
			'preview-text'   => 'Title Font',
			'preview-color'  => 'light',
			'font-family'    => 'Spartan',
			'font-weight'    => '700',
			'font-size'      => capture_px2rem( '32px' ),
			'line-height'    => '1.2',
			'color'          => '#000000',
			'letter-spacing' => capture_letter_spacing( 32, -16 ),
			'margin-bottom'  => capture_px2rem( '50px' ),
			'css-selectors'  => '.related-posts h4, #respond h4, .total-comments',
		],
	],
];
