<?php
/**
 * Single Tab
 *
 * @package Capture
 */

$menus['single-general'] = [
	'title' => esc_html__( 'General', 'capture' ),
	'desc'  => esc_html__( 'From here, you can control the appearance and functionality of your single posts page.', 'capture' ),
];

// Dependency check - Featured Image Size.
$featured_image_size = [
	'relation' => 'and',
	[
		'field'      => 'featured_image_size',
		'value'      => 'full',
		'comparison' => '==',
	],
];
// Breadcrumb Dependency.
$show_breadcrumb = [
	'field'      => 'show_breadcrumb',
	'value'      => '1',
	'comparison' => '==',
];
// Settings.
$sections['single-general'] = [
	[
		'id'       => 'show_single_featured',
		'type'     => 'switch',
		'title'    => esc_html__( 'Show Featured image', 'capture' ),
		'sub_desc' => esc_html__( 'Enable/Disable the Featured images in the single post.', 'capture' ),
		'std'      => '1',
	],
	[
		'id'       => 'featured_image_size',
		'type'     => 'button_set',
		'title'    => esc_html__( 'Header Size', 'capture' ),
		'sub_desc' => esc_html__( 'Choose the featured image size', 'capture' ),
		'options'  => [
			'default' => esc_html__( 'Content Size', 'capture' ),
			'full'    => esc_html__( 'Full Width', 'capture' ),
		],
		'std'      => 'default',
	],
	[
		'id'         => 'header_single_prev_next',
		'type'       => 'switch',
		'title'      => esc_html__( 'Show Next/ Previous Article', 'capture' ),
		'sub_desc'   => esc_html__( 'Use this button to show or hide preview and next article buttons.', 'capture' ),
		'std'        => '1',
		'dependency' => $featured_image_size,
	],
	[
		'id'         => 'featured_image_margin',
		'type'       => 'margin',
		'title'      => esc_html__( 'Header Margin', 'capture' ),
		'sub_desc'   => esc_html__( 'Set header margin from here.', 'capture' ),
		'left'       => false,
		'right'      => false,
		'std'        => [
			'top'    => capture_px2rem( '48px' ),
			'bottom' => capture_px2rem( '50px' ),
		],
		'dependency' => $featured_image_size,
	],
	[
		'id'         => 'featured_image_padding',
		'type'       => 'margin',
		'title'      => esc_html__( 'Header Padding', 'capture' ),
		'sub_desc'   => esc_html__( 'Set header padding from here.', 'capture' ),
		'left'       => false,
		'right'      => false,
		'std'        => [
			'top'    => '0',
			'bottom' => '0',
		],
		'dependency' => $featured_image_size,
	],
	[
		'id'       => 'mts_single_post_layout',
		'type'     => 'layout2',
		'title'    => esc_html__( 'Single Post Layout', 'capture' ),
		'sub_desc' => esc_html__( 'Customize the look of single posts', 'capture' ),
		'options'  => [
			'enabled'  => [
				'content' => [
					'label'     => esc_html__( 'Post Content', 'capture' ),
					'subfields' => [],
				],
				'tags'    => [
					'label'     => esc_html__( 'Tags & Social', 'capture' ),
					'subfields' => [],
				],
				'author'  => [
					'label'     => esc_html__( 'Author Box', 'capture' ),
					'subfields' => [],
				],
				'related' => [
					'label'     => esc_html__( 'Related Posts', 'capture' ),
					'subfields' => [
						[
							'id'       => 'mts_related_posts_taxonomy',
							'type'     => 'switch',
							'title'    => esc_html__( 'Related Posts Taxonomy', 'capture' ),
							'options'  => [
								'tags'       => esc_html__( 'Tags', 'capture' ),
								'categories' => esc_html__( 'Categories', 'capture' ),
							],
							'class'    => 'green',
							'sub_desc' => esc_html__( 'Related Posts based on tags or categories.', 'capture' ),
							'std'      => 'categories',
						],
					],
				],
			],
			'disabled' => [
				'subscribe' => [
					'label'     => esc_html__( 'Subscribe Box', 'capture' ),
					'subfields' => [],
				],
			],
		],
	],
	[
		'id'       => 'mts_single_headline_meta_info',
		'type'     => 'layout2',
		'title'    => esc_html__( 'Single Meta Info', 'capture' ),
		'sub_desc' => esc_html__( 'Organize how you want the post meta info to appear on single page', 'capture' ),
		'options'  => [
			'enabled'  => [
				'category' => [
					'label'     => esc_html__( 'Categories', 'capture' ),
					'subfields' => [
						[
							'id'    => 'mts_single_meta_info_category_icon',
							'type'  => 'icon_select',
							'title' => esc_html__( 'Select Icon', 'capture' ),
						],
					],
				],
				'date'     => [
					'label'     => esc_html__( 'Date', 'capture' ),
					'subfields' => [
						[
							'id'    => 'mts_single_meta_info_date_icon',
							'type'  => 'icon_select',
							'title' => esc_html__( 'Select Icon', 'capture' ),
						],
					],
				],
			],
			'disabled' => [
				'author'  => [
					'label'     => esc_html__( 'Author Name', 'capture' ),
					'subfields' => [
						[
							'id'    => 'mts_single_meta_info_author_icon',
							'type'  => 'icon_select',
							'title' => esc_html__( 'Select Icon', 'capture' ),
						],
					],
				],
				'comment' => [
					'label'     => esc_html__( 'Comment Count', 'capture' ),
					'subfields' => [
						[
							'id'    => 'mts_single_meta_info_comment_icon',
							'type'  => 'icon_select',
							'title' => esc_html__( 'Select Icon', 'capture' ),
						],
					],
				],
			],
		],
	],
	[
		'id'       => 'mts_author_comment',
		'type'     => 'switch',
		'title'    => esc_html__( 'Highlight Author Comment', 'capture' ),
		'sub_desc' => esc_html__( 'Use this button to highlight author comments.', 'capture' ),
		'std'      => '1',
	],
	[
		'id'       => 'show_breadcrumb',
		'type'     => 'switch',
		'title'    => esc_html__( 'Breadcrumbs', 'capture' ),
		'sub_desc' => esc_html__( 'Breadcrumbs are a great way to make your site more user-friendly. You can enable them by checking this box.', 'capture' ),
		'std'      => '0',
	],
	[
		'id'         => 'breadcrumb_font',
		'type'       => 'typography',
		'title'      => esc_html__( 'Breadcrumbs Font', 'capture' ),
		'std'        => [
			'preview-text'   => 'Breadcrumbs',
			'preview-color'  => 'light',
			'font-family'    => 'Spartan',
			'font-weight'    => '700',
			'font-size'      => '12px',
			'color'          => '#969696',
			'letter-spacing' => capture_letter_spacing( 12, 167 ),
			'line-height'    => '1.6',
			'additional-css' => 'text-transform: uppercase;',
			'css-selectors'  => '.breadcrumb, .rank-math-breadcrumb',
		],
		'dependency' => [
			'relation' => 'and',
			$show_breadcrumb,
		],
	],
];
