<?php
/**
 * Social Styling
 *
 * @package Capture
 */

$menus['social']['child']['social-styling'] = [
	'title' => esc_html__( 'Styling', 'capture' ),
	'desc'  => esc_html__( 'From here, you can control the elements of social sharing buttons styling.', 'capture' ),
];

// Dependency check that Floating Social Share is enabled.
$mts_social_button_position = [
	'relation' => 'and',
	[
		'field'      => 'mts_social_button_position',
		'value'      => 'floating',
		'comparison' => '==',
	],
];

$sections['social-styling'] = [

	[
		'id'         => 'social_styling_info',
		'type'       => 'info',
		'desc'       => esc_html__( 'No Styling options available for this Social Button layout.', 'capture' ),
		'dependency' => [
			'relation' => 'and',
			[
				'field'      => 'mts_social_button_position',
				'value'      => 'floating',
				'comparison' => '!=',
			],
		],
	],

	[
		'id'         => 'social_styling_heading',
		'type'       => 'heading',
		'title'      => esc_html__( 'Floating Social Share Styling', 'capture' ),
		'dependency' => $mts_social_button_position,
	],

	[
		'id'         => 'social_styling_margin',
		'type'       => 'margin',
		'title'      => esc_html__( 'Social Share Margin', 'capture' ),
		'sub_desc'   => esc_html__( 'Set social share buttons margin from here.', 'capture' ),
		'std'        => [
			'top'    => '5px',
			'right'  => '0',
			'bottom' => '5px',
			'left'   => capture_px2rem( '30px' ),
		],
		'dependency' => $mts_social_button_position,
	],

	[
		'id'         => 'social_floating_button_position',
		'type'       => 'margin',
		'title'      => esc_html__( 'Social Share Position', 'capture' ),
		'sub_desc'   => esc_html__( 'Set social share button position from here.', 'capture' ),
		'std'        => [
			'top'    => capture_px2rem( '76px' ),
			'right'  => 'auto',
			'bottom' => 'auto',
			'left'   => '0px',
		],
		'dependency' => $mts_social_button_position,
	],
	[
		'id'         => 'social_styling_border',
		'type'       => 'border',
		'title'      => esc_html__( 'Border', 'capture' ),
		'sub_desc'   => esc_html__( 'Select border', 'capture' ),
		'dependency' => $mts_social_button_position,
	],
	[
		'id'         => 'social_styling_background',
		'type'       => 'background',
		'title'      => esc_html__( 'Social Share Background', 'capture' ),
		'sub_desc'   => esc_html__( 'Set background color, pattern and image from here.', 'capture' ),
		'options'    => [
			'color'         => '',            // false to disable, not needed otherwise.
			'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
			'image_upload'  => '',            // false to disable, not needed otherwise.
			'repeat'        => [],       // false to disable, array of options to override default ( optional ).
			'attachment'    => [],       // false to disable, array of options to override default ( optional ).
			'position'      => [],       // false to disable, array of options to override default ( optional ).
			'size'          => [],       // false to disable, array of options to override default ( optional ).
			'gradient'      => '',            // false to disable, not needed otherwise.
			'parallax'      => [],       // false to disable, array of options to override default ( optional ).
		],
		'std'        => [
			'color'         => '#ffffff',
			'use'           => 'pattern',
			'image_pattern' => 'nobg',
			'image_upload'  => '',
			'repeat'        => 'repeat',
			'attachment'    => 'scroll',
			'position'      => 'left top',
			'size'          => 'cover',
			'gradient'      => [
				'from'      => '#ffffff',
				'to'        => '#000000',
				'direction' => '0deg',
			],
			'parallax'      => '0',
		],
		'dependency' => $mts_social_button_position,
	],

];
